***********************************
* CORRELATION BETWEEN HH INDEXES
* firmXmuni ID 
* year vs month concept of hiring 
***********************************

clear all 
set more off 
cap log close 

global output ${tab_regressioni}

local x first 
local g fuaX 
local c 1 
local t 1

* open dataset of HHs based on year concept of hiring 
use ${dta}/hh_index_contratto_`x'_`g'_tipo`c'_tenure`t'.dta, clear  
keep `g' contratto_ID_occ_`x'_c anno hh_new_hire tot_new_hire 
rename (hh_new_hire tot_new_hire) (hh_new_hire_y tot_new_hire_y)

* merge with dataset based on year-month concept of hiring  
merge 1:1 `g' contratto_ID_occ_`x'_c anno using ${dta}/hh_index_contratto_`x'_`g'_tipo`c'_tenure`t'_month12.dta, keepusing(hh_new_hire tot_new_hire) 
keep if _merge == 3
drop    _merge 
rename (hh_new_hire tot_new_hire) (hh_new_hire_m tot_new_hire_m)

* drop markets with missing occupation or geographical area
drop if mi(contratto_ID_occ_`x'_c) | mi(`g')

* log of HH indexes     
gen ln_firm_y = ln(hh_new_hire_y)
gen ln_firm_m = ln(hh_new_hire_m) 

* correlation coefficient 
gen weights = ""
gen corr = .
corr ln_firm_y ln_firm_m 
replace corr     = r(rho) in 1 
replace weights  = "Weights: No" in 1
corr ln_firm_y ln_firm_m [aw=tot_new_hire_y]
replace corr     = r(rho) in 2
replace weights  = "Weights: Yes" in 2
preserve 
keep corr weights 
order weights corr 
keep if corr != .
export excel using "${output}/corr_year_vs_month12.xls", sheet("Correlation coeff", replace) keepcellfmt firstrow(var)
restore 


*Stata Routine:
* The data must be by occupation, FUAX and year.
* The data should contain the HHI and the number of hires for each cell
* The HHI should vary between 0 and 1 (divide by 10000 if it varies between 0 and 10000)
* In the next 4 lines, include the name of your variables as indicated
global logHHIy      ln_firm_y // replace with the varname of the log HHI using the year concept 
global logHHIm      ln_firm_m // replace with the varname of the log HHI using the month-year concept 
global Hires        tot_new_hire_y // replace with the varname containing the number of new hires per cell (based on year concept)
global Countryname  "Italy" // replace with the name of your country

label var $logHHIy "log HHI year"
label var $logHHIm "log HHI month/year"
twoway scatter $logHHIm $logHHIy, msize(tiny) title($Countryname)  scheme(s2color)
graph export ${grafici}/HHIyHHIm12_$Countryname.png, as(png) replace 

gen coeff = .
regr $logHHIm $logHHIy [pw=$Hires]
replace coeff = _b[$logHHIy] in 1
preserve 
keep coeff
keep if coeff != .
export excel using "${output}/corr_year_vs_month12.xls", sheet("Regression coeff", replace) keepcellfmt firstrow(var)
restore 




