*****************************************
* CO DATASETS  
* PERFORM BASIC CLEANING 
* GENERATE STARTING DATASET FOR ANALYSIS 
*****************************************

clear all 
set more off 
cap log close 


** A. this dataset records contracts between TWA workers and user enterprises 
** for a given relationship between TWA workers and TWA agencies (id_somministrazione), 
** I retain the FIRST MISSION in the user enterprise and I keep the variable relative to the occupation and the working hours (full-time vs part-time) 
** ALL OTHER FEATURES (EMPLOYER, WORK MUNI, TYPE OF CONTRACT, START AND END DATE) ARE TAKEN FROM THE RELATIONSHIP BTW 
** TWA AGENCY AND TWA WORKERS 

gzuse  ${dati}/MISSIONI_II_2019_BDI.dta.gz, clear
gen random = rnormal(0,20)

gen data_inizio  = date(rapporto_datainizio, "MDY") 
gen data_fine    = date(dtcessazioneeffettiva, "MDY")
format data_inizio data_fine %td

gen     data_fine_fict = data_fine 
replace data_fine_fict = mdy(12,31,2099) if data_fine_fict == .
format  data_fine_fict %td 
gen     data_fineinv   = - data_fine_fict

** retain the first mission within id_lavoratore-id_somministrazione 
** if more than one mission starts at the earlies date, keep the one that lasts longer (data_fineinv serves to achieve that)
** if there are any remaining ties, choose one randomly (reproducible with seeds)
bys id_lavoratore id_somministrazione (data_inizio data_fineinv random): gen n=_n 
keep if n == 1

keep id_lavoratore id_somministrazione codqualificaprofessionale classificazioneprofessione codtipoorario 

tempfile tempdta 
save    `tempdta.dta', replace 

** B. this dataset contains all contracts between: (a) an employer and employee, without TWA mediation, (b) TWAs and their employees

gzuse ${dati}/CO_SOMM_II_2019_BDI.dta.gz, clear
gen random = rnormal(0,20)
count 

** B1. keep only contracts of type (b) and attach the relevant variables retrieved in step A (match_key: id_somministrazione)

preserve 

keep if fonte == 2 // keep contracts between TWAs and employees

keep id_datorelavoro id_lavoratore id_somministrazione ///
     rapporto_datainizio dtcessazioneeffettiva dttrasformazione codtipotrasformazione ///
     codcomunelavoro codprovincialavoro codregionelavoro ///
     codtipocontratto ///
     codsettore /// 
     random
     
merge 1:1 id_lavoratore id_somministrazione using `tempdta.dta', keepusing(codqualificaprofessionale classificazioneprofessione codtipoorario)
drop _merge 

tempfile tempdta
save    `tempdta.dta', replace 

restore 

*** B2.
** keep only contracts of type (a)
** for contracts of type (b), attach the dataset created in step A and B, so to have also the info on occupation 

drop if fonte == 2 // drop contracts between TWAs and employees
keep id_datorelavoro id_lavoratore id_somministrazione ///
     rapporto_datainizio dtcessazioneeffettiva dttrasformazione codtipotrasformazione ///
     codcomunelavoro codprovincialavoro codregionelavoro ///
     codtipocontratto ///
     codsettore ///  
     codtipoorario ///
     codqualificaprofessionale classificazioneprofessione /// 
     random 

append using `tempdta.dta'
count 

** gen date variables 
gen data_inizio    = date(rapporto_datainizio, "MDY") 
gen data_fine      = date(dtcessazioneeffettiva, "MDY")
gen data_trasf     = date(dttrasformazione, "MDY")
format data_inizio data_fine data_trasf %td

** preliminary filter #1: drop municipalities located outside of Italy 
drop if substr(codcomunelavoro,1,1) == "Z"


** cross-walk 1 
** merge info about municipality and NUTS3 (province) of work and residence according to the division in municipalities in place on 31-12-19
** as the number of municipalities and NUTS3 areas is declining in Italy over time, 
** this step is required to make geographical units consistent over time 

rename codcomunelavoro codice_comune_belfiore 
merge m:1 codice_comune_belfiore using ${dta}/elenco_comuni_CO_raccordo2019.dta, keepusing(codice_comune_belfiore2019 sigla_prov2019)
drop if _merge == 2
drop    _merge
rename (codice_comune_belfiore2019 sigla_prov2019) (codcomunelavoro19 siglaprovincialavoro19)
rename codice_comune_belfiore codcomunelavoro 

** cross-walk 2: cp11_5d <<>> isco08_4d for occupations
 
gen     temp = subinstr(codqualificaprofessionale,".","",.)
replace temp = "" if inlist(classificazioneprofessione, "CO_01", "N.D.") 
gen cp11_4d = substr(temp,1,4)
gen cp11_5d = substr(temp,1,5)
drop temp 

merge m:1 cp11_5d using ${dta}/raccordo_iscoIV_cpV_bdi.dta, keepusing(isco08_4d*)
drop if _merge == 2 
drop    _merge 

** in some few instances the isco08_4d code depends on the sector in which the firm is operating 
** these lines take care of those cases 

split codsettore, p(".") limit(2) destring
egen ate4d = concat(codsettore1 codsettore2)
rename codsettore1 ate2d

replace isco08_4d = isco08_4d_2 if cp11_5d == "12110" & ate2d == 3
replace isco08_4d = isco08_4d_2 if cp11_5d == "12210" & ate2d == 3
replace isco08_4d = isco08_4d_2 if cp11_5d == "12192" & ate2d >= 87 & ate2d <= 88
replace isco08_4d = isco08_4d_2 if cp11_5d == "12220" & ate2d >= 5  & ate2d <= 9
replace isco08_4d = isco08_4d_2 if cp11_5d == "12250" & ate2d == 56
replace isco08_4d = isco08_4d_2 if cp11_5d == "13110" & ate2d == 2 
replace isco08_4d = isco08_4d_3 if cp11_5d == "13110" & inlist(codsettore,"01.19.10","01.19.20","01.19.90")
replace isco08_4d = isco08_4d_2 if cp11_5d == "13120" & ate2d >= 5  & ate2d <= 9
replace isco08_4d = isco08_4d_2 if cp11_5d == "13150" & ate2d == 56
replace isco08_4d = isco08_4d_2 if cp11_5d == "13192" & ate2d >= 87 & ate2d <= 88 

drop isco08_4d_* codqualificaprofessionale classificazioneprofessione cp11_4d ///
codcomunelavoro codprovincialavoro codregionelavoro ate2d ate4d codsettore2 id_somministrazione

gzsave ${dta}/datasetCO_start.dta.gz, replace // this is the starting dataset 




