**************************
* GEN EXTENDED FUAs
**************************

clear all 
set more off 
cap log close 

** list of municipalities and corresponding nuts3 areas in 2019
use "${dta}/elenco_nuts3_2019.dta", clear
** merge list of municipalities and corresponding FUAs in 2019 
merge 1:1 codice_comune_belfiore2019 using "${dta}/elenco_fua_comuni_2019.dta", keepusing(cod_fua)
drop _merge 

rename (sigla_prov2019 cod_fua) (nuts3 fua)

** extended FUAS are built as: 
* (i)   FUAs +
* (ii)  Nuts3 with no intersection with FUAs +
* (iii) residual NUTS3 if at least 70% of their municipalities are not in FUAs

gen fua_miss = (fua == "")
bys nuts3: egen fua_miss_all = min(fua_miss) // dummy = 1 if the nut3 area there is no municipality belonging to a FUA
bys nuts3: egen double fua_miss_pc  = mean(fua_miss) // share of municipalities in the nuts3 area that do not belong to the FUAS

gen     extended_fua = fua
gen     tipo = 1 if fua != "" 
replace extended_fua = nuts3 if fua_miss_all == 1
replace tipo = 2 if fua_miss_all == 1
replace extended_fua = nuts3 if fua == "" & fua_miss_pc >= 0.7 & fua_miss_pc < 1 
replace tipo = 3             if fua == "" & fua_miss_pc >= 0.7 & fua_miss_pc < 1

egen long extended_fua2 = group(extended_fua)
rename (extended_fua extended_fua2) (temp extended_fua)

keep codice_comune_belfiore2 extended_fua tipo nuts3 temp

save ${dta}/elenco_extended_fua_comuni_2019.dta, replace 
