****************************************************
* RUN REGRESSIONS 
* ALTERNATIVE GEOGRAPHICAL DOMENSIONE OF THE LLM
* NUTS3 or FUAX
****************************************************


clear all 
set more off 
cap log close 

global output ${tab_regressioni}

global tipo first
global c 1 
global t 1 
 

  foreach geo in fua nuts3 {	
    global geo `geo'
    if "${geo}" == "nuts3" global geo1     sigla_prov2019 
    if "${geo}" == "fua"   global geo1     cod_fua 
    if "${geo}" == "nuts3" global namefile elenco_nuts3_2019 
    if "${geo}" == "fua"   global namefile elenco_fua_comuni_2019 
  
    
    ** open log file and define name for results table    
    
    cap log close 
    log using ${logs}/regressions_geo_${geo}.log, text replace 
    global filename_main reg_${geo}.xls
    
 
    ** open worker-level dataset 
    use ${dta}/dataset_new_hires_y.dta, clear 
 
    ** merge info about workers demographics 
    merge m:1 id_lavoratore using ${dta}/lavoratori_char_invarianti.dta
    drop if _merge == 2  
    drop    _merge 
   
     ** apply restrictions on the regression sample 
     
     ** 1. focus on 05-82, 90, 92-96 sectors
     gen temp = real(substr(contratto_ID_sec_${tipo}_c,1,2))
     keep if (temp >= 5 & temp <= 82) | temp == 90 | (temp >= 92 & temp <= 96) 
 
     ** 2. keep only permanent, temporary, apprenticeship contracts 
     gen contr_tipo = substr(contratto_ID_tipo_${tipo}_c,1,2)
     drop if contr_tipo != "A1" & contr_tipo != "A2" & contr_tipo != "A3" 
 
      ** 3. drop contracts with short tenure 	
     drop if tenure_c < 28 // drop new hires that have worked less than 28 days in the reference year 
   
     ** add info on geo   
     rename codcomunelavoro19 codice_comune_belfiore2019
     merge m:1 codice_comune_belfiore2019 using ${dta}/${namefile}.dta, keepusing(${geo1}) 
     drop if _merge == 2 
     drop    _merge
     rename codice_comune_belfiore2019 codcomunelavoro19
     rename ${geo1} ${geo}
    
    ** drop observations for which either the occupation or the geographical market is not defined (i..e the LLM is not defined)
     drop if mi(contratto_ID_occ_${tipo}_c) | mi(${geo})
   
    ** merge info about the HH index and the treatment in the local labor market (i.e. occupationXgeo)  
    ren anno year
    merge m:1 ${geo} contratto_ID_occ_${tipo}_c year using ${dta}/IV_hh_index_contratto_${tipo}_${geo}_tipo${c}_tenure${t}.dta, keepusing(hh_new_hire iv1)
    keep if _merge==3
    drop    _merge
    ren year anno
   
   * gen outcome 
   gen perm_${tipo} = (substr(contratto_ID_tipo_${tipo}_c,1,2) == "A1") if contratto_ID_tipo_${tipo}_c != ""
   
   ** gen further controls
   gen     orario_${tipo} = 1 if contratto_ID_orario_${tipo}_c == "F"
   replace orario_${tipo} = 2 if contratto_ID_orario_${tipo}_c == "P" | contratto_ID_orario_${tipo}_c == "M" | contratto_ID_orario_${tipo}_c == "V"
   replace orario_${tipo} = 3 if contratto_ID_orario_${tipo}_c == "N"
   gen eta_lavoratore = anno-anno_nascita // worker age 
   egen long llm            = group(contratto_ID_occ_${tipo}_c ${geo}) // local labor market FE (occupationXgeo)
   egen long llmXyear       = group(llm anno) // local labor market X year FE (occupationXgeoXyear)
   egen long firmXmuniXyear = group(id_datorelavoro codcomunelavoro19 anno) // firmXmuniXyear FE
   gen sector               = real(substr(contratto_ID_sec_${tipo}_c,1,2)) // 2-digit ateco FE
   
   ** gen log of the treatment variable 
   gen log_hh_new_hire =ln(hh_new_hire) // log of the HH index 
    
   ** define controls 
   global ctrl llm firmXmuniXyear donna edu_3cat eta_lavoratore orario_${tipo} empl_past_year sector 
    
   ** define cluster variable (for clustering standard errors)
   global clustervar llmXyear 
    
    di "Nobs"
    count 
    di "distinct ${geo}"
    distinct ${geo}
    
    ** run main regressions 

    *******************************************************
    * TYPE OF CONTRACT AT HIRING (1=PERMANENT) 
    *******************************************************
    
    ivreghdfe perm_${tipo} (log_hh_new_hire=iv1), abs(${ctrl}) cluster(${clustervar}) first savefirst
    display "#obs PERM IV is" %15.0f e(N_full)
    outreg2  using "${output}/${filename_main}", replace cti("permanent-IV") addstat("KP stat", e(widstat))  
    
    *******************************************************************************
    * TYPE OF CONTRACT THE YEAR AFTER (1=PERMANENT)
    * NB) these regressions are run only on new hires whose first contract with the
    * firmXmuni is not permanent 
     *******************************************************************************

    ivreghdfe conv_by_next_year  (log_hh_new_hire=iv1) if perm_${tipo}==0 & anno != 2018, abs(${ctrl}) cluster(${clustervar}) first savefirst
    display "#obs CONV IV is" %15.0f e(N_full)
    outreg2  using "${output}/${filename_main}", append cti("conv non perm -IV") addstat("KP stat", e(widstat))  
    
    log close 
  
    
   }







