***********************************************
* * Number of occupations per firmXmunicipality
 
***********************************************

clear all 
set more off 
cap log close 


global geo fuaX 
global tipo first 
global c 1
global t 1

* Use the same samples on which you have computed descriptive statistics in Table C1. Drop all other observations.
* In the next 3 lines, include the name of your variables as indicated
global occ          contratto_ID_occ_${tipo}_c       // replace with the varname of your occupation variable
global sircom       firmXmuni                        // replace with the varname containing firmXmunicipality identifiers 
global year         anno                              // replace ith the varname containing years


**** +++++++++++++++++++++++++++++++ *****
**** create regression sample 
**** +++++++++++++++++++++++++++++++ *****



  
     ** open worker-level dataset 
    use ${dta}/dataset_new_hires_y.dta, clear 
      
     ** merge info about workers demographics 
     merge m:1 id_lavoratore using    ${dta}/lavoratori_char_invarianti.dta
     drop if _merge == 2  // NB: we shall not have cases such that _merge == 1
     drop   _merge  
     
     ** apply restrictions on the regression sample 
      ** 1. focus on 05-82, 90, 92-96 sectors

     gen temp = real(substr(contratto_ID_sec_${tipo}_c,1,2))
     keep if (temp >= 5 & temp <= 82) | temp == 90 | (temp >= 92 & temp <= 96)
     ta temp 
     drop temp 

     ** 2. keep only permanent, temporary and apprentice contracts 
 
   
      gen contr_tipo = substr(contratto_ID_tipo_${tipo}_c,1,2)
      drop if contr_tipo != "A1" & contr_tipo != "A2" & contr_tipo != "A3" // elimino tutti i contratti diversi da tempo ind, tempo det, apprend
      ta contr_tipo
      
      ** 3. drop workers with short tenure 
 
      drop if tenure_c < 28 // drop new hires that have worked less than 28 days in the reference year 
      sum tenure_c  

      * merge info on fuaX
      rename codcomunelavoro19 codice_comune_belfiore2019
      
      merge m:1 codice_comune_belfiore2019 using ${dta}/elenco_extended_fua_comuni_2019.dta, keepusing(extended_fua) // extended FUAs
      drop if _merge == 2 
      drop    _merge

      rename codice_comune_belfiore2019 codcomunelavoro19
      rename (extended_fua) (fuaX) 
   
      * drop markets with missing occupation or geographical area 
      drop if mi(contratto_ID_occ_${tipo}_c) | mi(${geo})   
   
      ** egen firmXmuni ID 
      egen long firmXmuni = group(id_datorelavoro codcomunelavoro19) // firmXmuni
   
      di "Nobs"
      count 
      di "distinct ${geo}"
      distinct $geo


   **** +++++++++++++++++++++++++++ ****
   **** run code 
   **** +++++++++++++++++++++++++++ ****

* computing number of occupations at the firmXmunicipality-by-year level
preserve
ge one=1
collapse (count) one, by($occ $sircom $year)
duplicates tag $sircom $year, ge(numb_occ) 
replace numb_occ=numb_occ+1
drop one
sort $occ $sircom $year
save numb_occ, replace

*calculating the mean over the distribution of individual observation
restore
sort $occ $sircom $year
merge m:1 $occ $sircom $year using numb_occ
drop if _m==2
drop _m
sum numb_occ


disp "mean number of occupations: " r(mean)
gen meanocc = r(mean)
keep meanocc 
keep in 1 

export excel using "${tab_sumstat}/meanocc.xlsx", firstrow(var) replace 

