clear all 
set more off 
cap log close 

* Share of permanent new hires in the lowest decile of the HHI distribution

* Use the same sample on which you have computed descriptive statistics for the share of temporary contracts in new hires in Table C1. 
* Drop all other observations.
* In the next 2 lines, include the name of your variables as indicated

global output ${tab_sumstat}

local x first 
local g fuaX 
local c 1 
local t 1

** open worker-level dataset 
use ${dta}/dataset_new_hires_y.dta, clear 
 
** merge info about workers demographics 
merge m:1 id_lavoratore using    ${dta}/lavoratori_char_invarianti.dta
drop if _merge == 2  // NB: we shall not have cases such that _merge == 1
drop   _merge 
 
** apply restrictions on the regression sample 
** 1. focus on 05-82, 90, 92-96 sectors

gen temp = real(substr(contratto_ID_sec_${tipo}_c,1,2))
keep if (temp >= 5 & temp <= 82) | temp == 90 | (temp >= 92 & temp <= 96) 
ta temp 
drop temp 

** 2. keep only permanent, temporary and apprentice contracts  
gen contr_tipo = substr(contratto_ID_tipo_${tipo}_c,1,2)
drop if contr_tipo != "A1" & contr_tipo != "A2" & contr_tipo != "A3" // elimino tutti i contratti diversi da tempo ind, tempo det, apprend
ta contratto_ID_tipo_${tipo}_c
      
** 3. drop workers with short tenure 
drop if tenure_c < 28 // drop new hires that have worked less than 28 days in the reference year 
sum tenure_c 
 
** add info on geo

rename codcomunelavoro19 codice_comune_belfiore2019
merge m:1 codice_comune_belfiore2019 using ${dta}/elenco_extended_fua_comuni_2019.dta, keepusing(extended_fua) // extended FUAs
drop if _merge == 2 
drop    _merge

rename codice_comune_belfiore2019 codcomunelavoro19
rename (extended_fua) (fuaX) 
   
** drop observations for which either the occupation or the geographical market is not defined
drop if mi(contratto_ID_occ_${tipo}_c) | mi(${geo})
  
   
** merge info about the HH index in the local labor market (i.e. occupationXgeo) and about the treatment 
ren anno year
merge m:1 ${geo} contratto_ID_occ_${tipo}_c year using ${dta}/IV_hh_index_contratto_${tipo}_${geo}_tipo${c}_tenure${t}.dta, keepusing(hh_new_hire iv1)
keep if _merge==3
drop    _merge
ren year anno

* gen outcome 
gen perm_${tipo} = (substr(contratto_ID_tipo_${tipo}_c,1,2) == "A1") if contratto_ID_tipo_${tipo}_c != ""

di "Nobs"
count 
di "distinct ${geo}"
distinct ${geo}
   
**
global HHI  hh_new_hire  // replace with the varname of the HHI (or logHHI)
global perm perm_${tipo} // replace with the varname of your indicator variable for permanent contract

sum $HHI, detail
ge HHIp10=($HHI<=r(p10)&$HHI!=.)
sum $perm if HHIp10==1

* this is the mean share of perm contracts
disp "mean share perm contracts: " r(mean)
gen share_temporary = 100*(1-r(mean))
keep share_temporary 
keep in 1 

export excel "${tab_sumstat}/sharetemp_firstdecileHHI.xlsx", firstrow(var) replace keepcellfmt 

