**********************************
* SUM STAT ON WORKERS 
**********************************

clear all 
set more off 
cap log close 

global output ${tab_sumstat}

global tipo first 
global geo fuaX 
global c 1 
global t 1

** open worker-level dataset 
use ${dta}/dataset_new_hires_y.dta, clear 
 
** merge info about workers demographics 
merge m:1 id_lavoratore using    ${dta}/lavoratori_char_invarianti.dta
drop if _merge == 2  // NB: we shall not have cases such that _merge == 1
drop   _merge 
 
** apply restrictions on the regression sample 
** 1. focus on 05-82, 90, 92-96 sectors

gen temp = real(substr(contratto_ID_sec_${tipo}_c,1,2))
keep if (temp >= 5 & temp <= 82) | temp == 90 | (temp >= 92 & temp <= 96) 
ta temp 
drop temp 

** 2. keep only permanent, temporary and apprentice contracts  
gen contr_tipo = substr(contratto_ID_tipo_${tipo}_c,1,2)
drop if contr_tipo != "A1" & contr_tipo != "A2" & contr_tipo != "A3" // elimino tutti i contratti diversi da tempo ind, tempo det, apprend
ta contratto_ID_tipo_${tipo}_c
      
** 3. drop workers with short tenure 
drop if tenure_c < 28 // drop new hires that have worked less than 28 days in the reference year 
sum tenure_c 
 
** add info on geo 

rename codcomunelavoro19 codice_comune_belfiore2019

merge m:1 codice_comune_belfiore2019 using ${dta}/elenco_extended_fua_comuni_2019.dta, keepusing(extended_fua) // extended FUAs
drop if _merge == 2 
drop    _merge

rename codice_comune_belfiore2019 codcomunelavoro19
rename extended_fua fuaX
   
** drop observations for which either the occupation or the geographical market is not defined
drop if mi(contratto_ID_occ_${tipo}_c) | mi(${geo})
  
di "Nobs"
count 
di "N ${geo}"
distinct ${geo} 


 *** statistics  
   gen cat = "" 
   gen mean = .    // mean 
   gen sd   = .    // standard deviation 
   gen pc_miss = . // share of missing values 
   
   * gender (female = 1)
   qui sum donna if donna != . 
   replace mean = `r(mean)'        in 1 
   replace sd   = `r(sd)'          in 1 
   qui mdesc donna 
   replace pc_miss =  `r(percent)' in 1 
   replace cat = "Women"           in 1
   
   * age in years 
   gen eta = anno - anno_nascita 
   qui sum eta if eta != .
   replace mean = `r(mean)'        in 2 
   replace sd   = `r(sd)'          in 2 
   qui mdesc eta 
   replace pc_miss =  `r(percent)' in 2 
   replace cat = "Age"             in 2
   
   * full-time work
   gen     orario_${tipo} = 1 if contratto_ID_orario_${tipo}_c == "F"
   replace orario_${tipo} = 2 if contratto_ID_orario_${tipo}_c == "P" | contratto_ID_orario_${tipo}_c == "M" | contratto_ID_orario_${tipo}_c == "V"
   replace orario_${tipo} = 3 if contratto_ID_orario_${tipo}_c == "N"   
   gen     full_time = 0 if orario_${tipo} == 2 
   replace full_time = 1 if orario_${tipo} == 1
   qui sum full_time if full_time != .
   replace mean = `r(mean)'        in 3 
   replace sd   = `r(sd)'          in 3 
   qui mdesc full_time  
   replace pc_miss =  `r(percent)' in 3 
   replace cat = "Full-time work"  in 3
   
   * education 
   local c = 4
   ta edu_3cat, gen(edu_3cat_)
   foreach var in edu_3cat_1 edu_3cat_2 edu_3cat_3 edu_3cat_4 {
   	 if "`var'" == "edu_3cat_1" local cell Below upper secondary 
	 if "`var'" == "edu_3cat_2" local cell Upper secondary
	 if "`var'" == "edu_3cat_3" local cell Above upper secondary
	 if "`var'" == "edu_3cat_4" local cell Education Missing 
   	 qui sum `var' if `var' != .
         replace mean = `r(mean)'        in `c' 
         replace sd   = `r(sd)'          in `c' 
         qui mdesc `var'  
         replace pc_miss =  `r(percent)' in `c' 
         replace cat = "`cell'"          in `c' 
	 local c = `c' + 1 
   }   


   * employed past year 
   qui sum empl_past_year if empl_past_year != .
   replace mean = `r(mean)'            in 8 
   replace sd   = `r(sd)'              in 8 
   qui mdesc empl_past_year  
   replace pc_miss =  `r(percent)'     in 8 
   replace cat = "Employed past year"  in 8
   
   * permanent contract 
   gen perm_${tipo} = (substr(contratto_ID_tipo_${tipo}_c,1,2) == "A1") if contratto_ID_tipo_${tipo}_c != ""
   qui sum perm_${tipo} if perm_${tipo} != .
   replace mean = `r(mean)'                          in 9
   replace sd   = `r(sd)'                            in 9 
   qui mdesc perm_${tipo}  
   replace pc_miss =  `r(percent)'                   in 9 
   replace cat = "New hire on a permanent contract"  in 9
   
   * if hired on a temporary contract, working on a permanent contract next year 
   qui sum conv_by_next_year if conv_by_next_year != . & perm_${tipo} == 0
   replace mean = `r(mean)'                          in 10
   replace sd   = `r(sd)'                            in 10
   qui mdesc conv_by_next_year if anno < 2018  
   replace pc_miss =  `r(percent)'                   in 10 
   replace cat = "Conversion to permanent contract"  in 10
   
    
   * approximate to the fourth decimal 
   replace mean    = round(mean, 0.0001)
   replace sd      = round(sd, 0.0001)
   replace pc_miss = round(pc_miss, 0.0001)
   
   keep cat mean sd pc_miss 
   keep if cat != ""
   
   export excel using ${output}/sum_stat_workers.xlsx, firstrow(var) replace 
