*THIS CODE:

*[1] OPENS THE DATASET "UDDAUPD01" (AVAILABLE FROM STATISTICS DENMARK);
*[2] MERGES STANDARD EDUCATION CODES;
*[3] CREATES A CATEGORICAL EDUCATION VARIABLE; 
*[4] SAVES TWO DATASETS WITH INFORMATION ON EDUCATION TO BE USED LATER IN THE ANALYSIS ("Education Categories.dta" AND "Education Categories_sorted by PNR.dta").

clear 
use "uddaupd01.dta"

format almaudd %6.0g
format hfaudd %6.0g
format erhaudd %6.0g

sort hfaudd

preserve
import excel "Education Codes.xlsx", sheet("Sheet1") clear
gen educ_cat = substr(B,1,1)
destring educ_cat, replace
replace educ_cat = . if B == "9 Not elsewhere classified"

rename A hfaudd
replace educ_cat = 1 if hfaudd == 1
drop C
sort hfaudd
tempfile temp
save `temp', replace
restore

*MERGE CATEGORISATION OBTAINED FROM STATISTICS DENMARK AND FORMATTED MANUALLY

merge m:1 hfaudd using `temp'
drop if _m == 2
drop _merge

tab educ_cat, missing

replace educ_cat = 1 if (educ_cat < 3)
replace educ_cat = 2 if (educ_cat == 3 )
replace educ_cat = 3 if educ_cat > 3 & educ_cat != .

tab educ_cat, missing

rename uddaupd01sourceyear year

destring pnr, replace
replace year = year - 2000

keep year pnr educ_cat hfaudd
sort year pnr

save "Education Categories.dta", replace

by pnr, sort: egen maxeduc = max(educ_cat)
keep if educ_cat == maxeduc
drop maxeduc
duplicates drop pnr, force

sort pnr

save "Education Categories_sorted by PNR.dta", replace

exit