*THIS CODE:

*[1] COMPUTES THE CONCENTRATION INDEX A LA ARNOLD 2021 AND GENERATES A DATASET TO BE MERGED WITH THE MAIN ONE DURING THE ANALYSIS.

clear

*****************************************************
************* TRANSITION PROB (ARNOLD'S HHI) ********
*****************************************************

*** UNTIL THE FIFTH STEP (FINAL CONSTRUCTION OF HHI) YOU CAN WORK WITH THE REGRESSION DATASET (as you do not need the population to estimate transition probabilities)

* you should be able to run this programme by simply inserting the name of your variables 
global panel = "data_for_regressions_10_18_komcvrfuaX" // panel dataset containing your observations 
global year year // year variable (two digits)
global maxyear = 18 // last calendar year in the dataset (string variable)
global minyear = 10 // first calendar year in the dataset (string variable)
global newminyear = 11 // calendar year after the first one in the dataset (string variable)
global dp2 ansdage_2008 // employment spell duration in days
global pcs pcs // four-digit occupation codes
global nbheur loentimer // total number of hours in the employment spell
global netnet smalt_loen_beloeb // gross annual earnings 
global nninouv pnr // individual identifier
global sircom komcvr // firmXmunicipality identifier
global nic nic // establishment identifier - this is necessary in PT and DK, I believe. In DE & FR $nic = $sircom
global HHIdataset = "HHI\HHI2_HP_komcvrfuaX_pcs41" // file that contains original HHIs (I assume that it also contains other variables as indicated below)
global Z_P0 Z_P0 // number of employees in the LLMxYear, as used to calculate employment HHIs. I assume this is contained in HHIdataset (if not, it needs to be computed)
global fuaX fuaX // identifier of the Functional Area
global population = "idanupd" // name of the population dataset
global ftpt full_time // variable taking value 1 if full time and 0 otherwise
global maxdays = 270 // value indicating a 9-months of employment spell in the year in days (270 in France) // it cannot be one year in PT & DK, but using the date of hiring it can be 9 months
global otherfilters = "drop if typ_emploi==6|typ_emploi==7" // specific filters normally used to compute HHIs (for me only "drop interns") - see sixth step
* The following new global macro is introduced because we lose one year if we requires that individuals be there the year after
* set it as "global maxyear1 = maxyear" if we do not use that condition
global maxyear1 = $maxyear - 1 


**** first preliminary step: construct a variable identifying new hires (normally you should have done it already - but you may
**** find it convenient to follow these steps if you want to run the code by only inputing the macro names above)
**** in fact this is unnecessary now and could be skipped, except that you must eliminate it from the merges below
use $panel , clear

* absent/present year before
ge P1y = ($dp2 !=.|$netnet >0)

collapse (max) P1y, by($nninouv $sircom year)
destring $year, ge(an) // generate a numeric variable for year
ge an = year
compress
replace an=an+1
drop if an==$maxyear +1
rename P1y P1ysircom

save P1sircom, replace

collapse (max) P1ysircom, by($nninouv an)
rename P1y P1y
sort $nninouv an
save P1, replace

**** second preliminary step: construct a variable identifying those who remain in the firmXmunicipality the year after 
* absent/present year after

use $panel.dta, clear

ge PFy = ($dp2 != .|$netnet >0)

collapse (max) PFy, by($nninouv $sircom year)
destring year, ge(an)
gen an = year
compress
replace an=an-1
drop if an==$minyear
rename PFy PFysircom
sort $nninouv $sircom an
save PFsircom, replace

collapse (max) PFysircom, by($nninouv an)
rename PFysircom PFy
sort $nninouv an
save PF, replace

***** First step: create a database with variables for observations at t and at t-1 (to avoid tsetting)

** create a dataset with relevant variables for job matches in the previous year
use $panel , clear  

destring $year, ge(an) // create numeric variable for years
gen an = year
replace an=an+1

drop if an>=$maxyear // note: this includes a correction of an error in the previous version (not influential)

*** first condition for identification of main job: main job one year ago should be 9-month duration and full time
keep if $ftpt == 1
keep if $dp2 >= $maxdays

rename $pcs pcs_1
rename $dp2 dp2_1
rename $nbheur nbheur_1
rename $netnet netnet_1

keep an $sircom $nninouv $nic dp2 pcs nbheur netnet // $nic inserted to correct a mistake in the previous version (important for DK & PT)

drop if mi(pcs)
sort $nninouv $sircom $nic an
save indiv_origin, replace

*** merging with variable containing containing current job matches
use $panel , clear

destring $year, ge(an)
gen an = year
drop if an==$minyear

keep if $dp2 >=30 // note that this is the standard condition on durations - at least 9 months applies only to the year before

				drop if arb_hoved_bra_db07 < 51000
				drop if (arb_hoved_bra_db07 >= 840000 & arb_hoved_bra_db07 < 900000) | (arb_hoved_bra_db07 >= 910000 & arb_hoved_bra_db07 < 920000) | arb_hoved_bra_db07 >= 970000				
				
* find new hires (unnecessary now)
	
* find stayers the year after
drop if an==$maxyear1 + 1

sort $nninouv $sircom an
merge m:1 $nninouv $sircom an using PFsircom // m:1 = error corrected for DK and PT
drop if _m==2
drop _m		
					
*keep full-timers only and only if present the year after (even if not full time)
keep if $ftpt == 1	
keep if PFy == 1 // neutralise this if if we do not use the condition of present the year after				

* merging with records of the previous year				
sort $nninouv $sircom $nic an
merge 1:1 $nninouv $sircom $nic an using indiv_origin // $nic inserted to correct a mistake in the previous version (important for DK & PT)
ren _m mergeorigin

* saving a temporary file containing, on the same line, 
save temp_t, replace

*** second step: identifying the main job previous year among those with at least 9-months duration
* looping over years
foreach y of numlist $newminyear / $maxyear1 {
	use temp_t, clear

	ge p1=1 

	keep if an==`y'

	* second condition: pick that with the same occupation, if there is any
	ge occorigin=""
	levelsof pcs_1, local(pcs)

	foreach p of local pcs {
		disp `y' "  `p'"
		ge p1_`p'=(pcs_1=="`p'")
		egen maxp1_`p'=max(p1_`p'), by($nninouv )
		replace occorigin="`p'" if $pcs =="`p'"&maxp1_`p'==1
		drop p1_`p' maxp1_`p'
	}
	
	* indicators for max duration, max hours (if same duration) and max salary (if same duration and hours)
	egen maxdp=max(dp2_1), by($nninouv )	
	egen maxh=max(nbheur_1)	if abs(maxdp-dp2_1)<1, by($nninouv )
	egen maxw=max(netnet_1)	if abs(maxdp-dp2_1)<1&abs(maxh-nbheur_1)<1, by($nninouv )
	
	** NOTE: in order to "transfer" the occupation of origin from one job match the year before to a current one, I use the operator "mode"
	* which works also for alphanumeric variables
	
	
	* third condition: pick the one with the longest duration, if there are no ties
	* identify occupations of job matches with longest duration 
	ge occmode=pcs_1 if abs(maxdp-dp2_1)<1&occorigin==""
	* tag = number of maximum duration minus 1 per individual
	duplicates tag $nninouv if occmode!="", ge(tag)
	* tag2 = number of maximum duration minus 1 per individual and occupation
	duplicates tag $nninouv occmode if occmode!="", ge(tag2)
	* choose the occupation with the modal maximum duration if this is unique (per individual)
	egen mode=mode(occmode) if tag==tag2, by($nninouv )
	replace occorigin=mode if occorigin==""
	drop mode occmode tag tag2
	

	* fourth condition: among the new ties, pick the one with the longest hours, if there are no new ties 
	* (occmode, tag, tag2 & mode play the same role as before)
	ge occmode=pcs_1 if abs(maxdp-dp2_1)<1&abs(maxh-nbheur_1)<1
	duplicates tag $nninouv if occmode!="", ge(tag)
	duplicates tag $nninouv occmode if occmode!="", ge(tag2)
	egen mode=mode(occmode) if tag==tag2, by($nninouv )
	replace occorigin=mode if occorigin==""
	drop mode occmode tag tag2
	
	* fifth condition: among the new ties, pick the one with the highest salary, if there are no new ties
	* (occmode, tag, tag2 & mode play the same role as before)
	ge occmode=pcs_1 if abs(maxdp-dp2_1)<1&abs(maxh-nbheur_1)<1&abs(maxw-netnet_1)<1
	duplicates tag $nninouv if occmode!="", ge(tag)
	duplicates tag $nninouv occmode if occmode!="", ge(tag2)
	egen mode=mode(occmode) if tag==tag2, by($nninouv )
	replace occorigin=mode if occorigin==""
	drop mode occmode tag tag2
	
	* 	sixth condition: among the new ties, pick the most frequent, if there are no new ties
	ge occmode=pcs_1 if abs(maxdp-dp2_1)<1&abs(maxh-nbheur_1)<1&abs(maxw-netnet_1)<1&occorigin==""
	egen mode=mode(occmode), by($nninouv )
	replace occorigin=mode if occorigin==""
	drop mode occmode

	* 	seventh condition: among the new ties, pick one at random
	set seed 1
	ge u=runiform()
	ge d=abs((_n/_N)-u)
	egen mind=min(d) if abs(maxdp-dp2_1)<1&abs(maxh-nbheur_1)<1&abs(maxw-netnet_1)<1&occorigin=="", by($nninouv )
	ge occmode=pcs_1 if abs(maxdp-dp2_1)<1&abs(maxh-nbheur_1)<1&abs(maxw-netnet_1)<1&abs(mind-d)<0.00000001&occorigin==""
	egen mode=mode(occmode), by($nninouv )
	replace occorigin=mode if occorigin==""
	drop mode occmode
		
** cleaning up (normally not needed)
	keep if $pcs!=""
	keep if occorigin!=""
	
	compress
	
	save temp_t`y', replace
	
}


*** third step: construct a squared matrix of occupation
use $HHIdataset, clear
collapse (sum) $Z_P0, by($pcs )
ge one=1
ren $Z_P0 Z_P00
sort one
save pcs_list, replace
ren $pcs occorigin
ren $Z_P0 Z_P01
sort one
joinby one using pcs_list
keep $pcs occorigin Z_P01 Z_P00
sort $pcs occorigin
save pcs_squared, replace

*** fourth step: transition probabilities and factors (that is relative probabilities divided by relative employment)

* create a frequency dataset by current and previous year occupations (main job only as defined above for previous year) 
clear
set obs 1
ge v1=.
save tprob, replace

foreach y of numlist $newminyear / $maxyear1 {
*foreach y of numlist 12 / 16 {
	use temp_t`y', clear
	collapse (sum) p1, by(occorigin $pcs )
	replace p1=0 if p1==.
	ge year="`y'"
	append using tprob
	save tprob, replace

	
}

drop if p1==.

* summing frequency over years
collapse (sum) p1, by($pcs occorigin)
label var p1 "frequency of occupation couple"
sort $pcs occorigin
merge 1:1 $pcs occorigin using pcs_squared
drop if _m==1
replace p1=0 if p1==.
* marginal distributions
egen den1=total(p1), by(occorigin) // occupation year before
egen den0=total(p1), by($pcs ) // occupation current year
* probability of a given occupation the year before conditional on the occupation of origin
ge prob=p1/den1
replace prob=0 if prob==.
* probability of remaining in the same occupation conditional on the occupation of origin
ge tden=prob if occorigin==$pcs
* reporting the probability of remaining in the same occupation conditional on the occupation of origin to all couples with same occorigin
	egen den=max(tden), by(occorigin)
* relative probability (as in Arnold's formula	
ge relprob=prob/den
* relative factor (as in Arnold's: (Prob_m_to_k/Prob_m_to_m)/(E(Lk/ELm)
* assumption E(Lk/ELm) in Arnold can be approximated by Z_P00/Z_P01
ge relfactor=relprob*(Z_P01/Z_P00)
drop den tden den1 den0 Z_P00 Z_P01 _m
sort $pcs
	compress
save tprob, replace	
	
* fifth step: denominators of shares

foreach y of numlist $newminyear / $maxyear {
use $HHIdataset, clear
keep if $year =="`y'"
keep $pcs $fuaX $year $Z_P0
sort $pcs
joinby $pcs using tprob
ge Z_P0prob=$Z_P0 * relprob
ge Z_P0factor=$Z_P0 * relfactor
ge one=($pcs ==occorigin)
ge Z_P1 = $Z_P0 * one // note this was an error in the previous version. Z_E*one should have been $Z_E*one (I think it had no consequences)
collapse (sum) Z_P0 Z_P0p Z_P0f Z_P1, by(occorigin $fuaX $year)
ren occorigin $pcs
compress
sort $pcs $fuaX $year
save ArnDen`y', replace 

}


* sixth step: numerator of shares and final calculation
** YOU MAY NEED TO ADAPT THIS PART

				clear
						* create an empty dataset
						gen year=""
						save ArnoldHHI, replace 
						
					foreach year of numlist $newminyear / $maxyear {
										
					disp   "`year'"
					
					***** Part I: compute aggregates at the `zone'XpcsXyear (geo area by occupation by year) level
					
					use $population`year'
					
					*other filters for the computation of HHIs (e.g. drop interns) 
					*$otherfilters
				
					*keep nbhours>0
					keep if $nbheur>0
							
					**** define new hires and employment
					
					**** case 1: at least 1 month of tenure
					*** first step: construct indicators of presence and absence in the same plant for the current and the previous year
					* construction of the indicators for presence in the current year and absence in the previous year 
						ge P0 = $dp2 >=30 //*note: we do not change this to maintain consistency with our HHI (based on employment)
						ge A1 = 1
									
					*** second step: construct indicators of absence in the firm for the previous year (according to the different definitions in cases 1, 2 and 3 - see just above)
					egen minA1 = min(A1), by($nninouv $sircom )
					
					*** third step: effectively define new hires // not needed anymore
					
					gen not_new_hire = (ansxtilb == "T1" | ansxtilb == "T2")
					gen Hire = (ansaar == `year') & not_new_hire != 1
					replace Hire = . if ansdage_2008 < 30							
					
					*keep industries
					*keep if (substr($apet , 1, 2)>="05"&substr($apet , 1, 2)<="82")|substr($apet , 1, 2)=="90"| ///
						*substr($apet , 1, 2)>="92"&substr($apet , 1, 2)<="96"
					drop if arb_hoved_bra_db07 < 51000
					drop if (arb_hoved_bra_db07 >= 840000 & arb_hoved_bra_db07 < 900000) | (arb_hoved_bra_db07 >= 910000 & arb_hoved_bra_db07 < 920000) | arb_hoved_bra_db07 >= 970000		
						
					*cleanup occupational data
					tostring disco_kode, replace
					replace disco_kode = upper(disco_kode)
					replace disco_kode = substr(disco_kode, 1, 4)
			
					gen pcs = disco_kode
					drop if mi(pcs)
					
					
						* collapse at the firm level
						collapse (sum) P0, by($sircom $fuaX $pcs)
						
	
						* compute the total number of firmXmunicipalities
						preserve
						collapse P0, by($sircom $fuaX)
						drop P0
						ge number=_n
	
						sort $sircom $fuaX
						save sf, replace
						restore
						
						sort $sircom $fua
						merge m:1 $sircom $fuaX using sf
						drop _m
						
						
						*** create an indicator for block-by-block joinby
						ge N=floor(number/10000) 
						drop number
						sum N
						global max=r(max)+1
						disp $max
						
						compress
						save P0_`year', replace
							
				*looping over occupations (1st digit) to compute empty datasets to be used for the numerator of shares
				foreach pcs1 of numlist 1/9 {	
				
				disp "`pcs1'"
					* compute 
					clear
					set obs 1
					ge v1=1
					compress
					save ArnNum`year'`pcs1', replace
				}	
				* looping blocks of firmXmunicipality and 1 digit occupations (to avoid too large intermediate datasets)
				* and compute Arnold's numerators of shares
					local x=0	
					while `x' < $max {
						disp `x'
			
										
						use P0_`year', clear
							keep if N==`x'
							sort $pcs
						
						*joinby transition probabilities
						joinby $pcs using tprob
						
						* compute numerator of shares
						
						* brick to construct Arnold's shares
						ge Hfactor=P0*relfactor
						* alternative way using only relative probabilities
						ge Hprob=P0*relprob
						* brick to construct standard HHI (to check consistency)
						ge one=($pcs == occorigin)
						ge H1 = P0*one
						gen H1alt = P0
						
						* computing numerator of shares as weighted sums (as in Arnold)
						collapse (sum) Hp Hf H1 H1alt, by($sircom occorigin $fuaX )
						ren occorigin $pcs
						drop if Hfactor==0
						drop if $fuaX ==""
						
						*appending (looping on occupations - again to avoid too large datasets) 
						compress
					foreach pcs1 of numlist 1/9 {	
										disp "`pcs1'"
 
						preserve
						keep if substr($pcs ,1,1)=="`pcs1'"

						append using ArnNum`year'`pcs1'
						sort $pcs $fuaX				
						save ArnNum`year'`pcs1', replace
						restore
					}
									local x = `x'+1					
						
						}
						
					* looping over 1 digit occupations to compute final Arnold's HHI
					foreach pcs1 of numlist 1/9 {	
										disp "`pcs1'"
										
						use ArnNum`year'`pcs1', clear				
						drop if v1==1
					
					
					* merge with local labour market Arnold aggregate denominators
						merge m:1 $pcs $fuaX using ArnDen`year'
						keep if _m==3

					* squared shares of employment using Arnold factors	
						gen HHI_A=(Hfactor/Z_P0factor)^2
					* squared shares of employment using Arnold probabilities	
						gen HHI_a=(Hprob/Z_P0prob)^2
						
					* check term
						gen HHI_H=(H1/Z_P1)^2					
						
					* drop further errors in the occupation and geographical area variables, if any
						drop if $pcs ==""
						drop if $fuaX ==""
		
				* calculating HHI by summing up squared shares
				collapse (sum) HHI_a HHI_A HHI_H, by($fuaX $pcs)

						gen year="`year'"
						
					* append to previous years, if any
						append using ArnoldHHI
					* saving
						drop if year==""
						
						label var HHI_A "Arnold's HHI"
						label var HHI_a "Arnold's HHI but computed using only relative probabilities" // we will not use this one
						label var HHI_H "Standard HHI" // you might want to compare these values with those that you have already used in the regressions (they should be the same)
						
						sort year fuaX pcs 
						save ArnoldHHI, replace 
						
						erase ArnNum`year'`pcs1'.dta
						
					}
				}

* erasing unnecessary temp files				
				
erase temp_t.dta

foreach y of numlist $minyear / $maxyear {
	cap erase temp_t`y'.dta
	cap erase ArnDen`y'.dta
	cap erase P0_`y'.dta
	}

exit