clear
clear matrix
clear mata
set maxvar 120000

local minyear 11
local maxyear 18
local aggregate komcvr cvr
local aggregateL komcvr cvr
local m = 1
local x = 2
local zone fuaX dep fua1
local zoneL fuaX dep fua1
local vars "ln_hourly_wage ln_hhi ln_hhi_E arb_hoved zone_num year cvr pnr pcs kom full_time stable_job emp_prev_year emp_next_year lbnr Hire IV_*"

capture log close

log using "TABLES AND FIGURES_DENMARK", replace


************ TABLE 1 ************

use "data_for_regressions_`minyear'_`maxyear'_komcvrfuaX.dta", clear

gen hhi = exp(ln_hhi)
preserve
collapse (mean) hhi (sum) Hire, by(year pcs fuaX)
sum hhi [w = Hire] if hhi != 0 & hhi != ., detail
restore


************ TABLE 2 ************

use "data_for_regressions_`minyear'_`maxyear'_komcvrfuaX.dta", clear

winsor2 smal_timeloen, cuts(1 99) trim
replace ln_hourly_wage = ln(smal_timeloen_tr)

gen daily_wage = exp(ln_daily_wage)
winsor2 daily_wage, cuts(1 99) trim
replace ln_daily_wage = ln(daily_wage_tr)


global fixed = "id occ#geo firm#munic#year firm#nic aldernov_n"

*DAILY WAGES

ivreghdfe ln_daily_wage Hire emp_prev_year (ln_hhi = IV_mH) if full_time, absorb($fixed) cluster(cluster) first

preserve
keep if e(sample)
reghdfe ln_hhi IV_mH Hire emp_prev_year if full_time, absorb($fixed) cluster(cluster)
restore


************ TABLE 3 ************

*N/A

************ TABLE 4 ************

use "data_for_regressions_`minyear'_`maxyear'_komcvrfuaX.dta", clear

winsor2 smal_timeloen, cuts(1 99) trim
replace ln_hourly_wage = ln(smal_timeloen_tr)

gen daily_wage = exp(ln_daily_wage)
winsor2 daily_wage, cuts(1 99) trim
replace ln_daily_wage = ln(daily_wage_tr)

global fixed = "id occ#geo firm#munic#year firm#nic aldernov_n"

*PANEL A

ivreghdfe ln_hourly_wage full_time Hire emp_prev_year (ln_hhi = IV_mH) if full_time, absorb($fixed) cluster(cluster)

*PANEL B

*HOURLY WAGES

ivreghdfe ln_hourly_wage full_time Hire emp_prev_year (ln_hhi = IV_mH), absorb($fixed) cluster(cluster)


************ TABLE 5 ************

use "data_for_regressions_`minyear'_`maxyear'_komcvrfuaX.dta", clear

winsor2 smal_timeloen, cuts(1 99) trim
replace ln_hourly_wage = ln(smal_timeloen_tr)

gen daily_wage = exp(ln_daily_wage)
winsor2 daily_wage, cuts(1 99) trim
replace ln_daily_wage = ln(daily_wage_tr)

global fixed = "id occ#geo firm#munic#year firm#nic aldernov_n"

gen int_hire_hhi = ln_hhi*Hire
gen z_int_hire_mH = IV_mH*Hire

gen Incum = (Hire == 0)
gen int_incum_hhi = ln_hhi*Incum
gen z_int_incum_mH = IV_mH*Incum

*DAILY WAGES

ivreghdfe ln_daily_wage full_time Hire emp_prev_year (int_incum_hhi int_hire_hhi = z_int_incum_mH z_int_hire_mH) if full_time, absorb($fixed) cluster(cluster)
test int_incum_hhi - int_hire_hhi = 0


************ TABLE 6 ************

*N/A


************ TABLE 7 ************

*N/A


************ TABLE 8 ************

*N/A


************ FIGURE 1A, 2A ************

use "data_for_regressions_`minyear'_`maxyear'_komcvrfuaX.dta", clear

winsor2 smal_timeloen, cuts(1 99) trim
replace ln_hourly_wage = ln(smal_timeloen_tr)

gen daily_wage = exp(ln_daily_wage)
winsor2 daily_wage, cuts(1 99) trim
replace ln_daily_wage = ln(daily_wage_tr)

global fixed = "id occ#geo firm#munic#year firm#nic aldernov_n"

gen Young = (aldernov_n <= 24)
gen Old = (aldernov_n > 24 & aldernov_n != .)

gen Man = (kon_n == 1)
gen Woman = (kon_n == 2)

gen int_young_hhi = ln_hhi*Young
gen z_int_young_mH = IV_mH*Young

gen int_old_hhi = ln_hhi*Old
gen z_int_old_mH = IV_mH*Old

gen int_man_hhi = ln_hhi*Man
gen z_int_man_mH = IV_mH*Man

gen int_woman_hhi = ln_hhi*Woman
gen z_int_woman_mH = IV_mH*Woman


*DAILY WAGES

************ FIGURE 1A ************

ivreghdfe ln_daily_wage full_time Hire emp_prev_year (int_man_hhi int_woman_hhi = z_int_man_mH z_int_woman_mH) if full_time, absorb($fixed) cluster(cluster)
test int_man_hhi - int_woman_hhi = 0

************ FIGURE 2A ************

ivreghdfe ln_daily_wage full_time Hire emp_prev_year (int_old_hhi int_young_hhi = z_int_old_mH z_int_young_mH) if full_time, absorb($fixed) cluster(cluster)
test int_old_hhi - int_young_hhi = 0


************ FIGURE 3A ************

use "data_for_regressions_`minyear'_`maxyear'_komcvrfuaX.dta", clear

sort pnr
merge m:1 pnr using "Nationality.dta" 

drop if _merge == 2
drop _merge

capture drop int_Home_hhi
capture drop z_int_Home_mH

gen int_Home_hhi = ln_hhi*Home
gen z_int_Home_mH = IV_mH*Home

capture drop int_Foreign_hhi
capture drop z_int_Foreign_mH

gen int_Foreign_hhi = ln_hhi*Foreign
gen z_int_Foreign_mH = IV_mH*Foreign

winsor2 smal_timeloen, cuts(1 99) trim
replace ln_hourly_wage = ln(smal_timeloen_tr)

gen daily_wage = exp(ln_daily_wage)
winsor2 daily_wage, cuts(1 99) trim
replace ln_daily_wage = ln(daily_wage_tr)

global fixed = "id occ#geo firm#munic#year firm#nic aldernov_n"

*DAILY WAGES

ivreghdfe ln_daily_wage Hire emp_prev_year (int_Home_hhi int_Foreign_hhi = z_int_Home_mH z_int_Foreign_mH) if full_time, absorb($fixed) cluster(cluster) first
test int_Home_hhi - int_Foreign_hhi = 0


************ FIGURE 4A ************

use "data_for_regressions_`minyear'_`maxyear'_komcvrfuaX.dta", clear

sort year pnr
merge m:1 year pnr using "Education Categories.dta"

drop if _merge == 2
drop _merge

gen educ_cat_new = educ_cat
drop educ_cat
tab educ_cat_new, missing

sort pnr
merge m:1 pnr using "Education Categories_sorted by pnr.dta"
drop if _merge == 2
drop _merge

replace educ_cat_new = educ_cat if educ_cat_new == .
drop educ_cat

rename educ_cat_new educ_cat

tab educ_cat, missing g(educ_cat_)

gen HighEduc = 0 if (educ_cat == 1)
replace HighEduc = 1 if (educ_cat == 2 | educ_cat == 3)

gen LowEduc = 1 if (educ_cat == 1)
replace LowEduc = 0 if (educ_cat == 2 | educ_cat == 3)

capture drop int_HighEduc_hhi
capture drop z_int_HighEduc_mH

gen int_HighEduc_hhi = ln_hhi*HighEduc
gen z_int_HighEduc_mH = IV_mH*HighEduc

capture drop int_LowEduc_hhi
capture drop z_int_LowEduc_mH

gen int_LowEduc_hhi = ln_hhi*LowEduc
gen z_int_LowEduc_mH = IV_mH*LowEduc

winsor2 smal_timeloen, cuts(1 99) trim
replace ln_hourly_wage = ln(smal_timeloen_tr)

gen daily_wage = exp(ln_daily_wage)
winsor2 daily_wage, cuts(1 99) trim
replace ln_daily_wage = ln(daily_wage_tr)

global fixed = "id occ#geo firm#munic#year firm#nic aldernov_n"

*DAILY WAGES

ivreghdfe ln_daily_wage Hire emp_prev_year (int_HighEduc_hhi int_LowEduc_hhi = z_int_HighEduc_mH z_int_LowEduc_mH) if full_time, absorb($fixed) cluster(cluster) first
test int_HighEduc_hhi - int_LowEduc_hhi = 0


************ FIGURE 1.1 ************

use "data_for_regressions_`minyear'_`maxyear'_komcvrfuaX.dta", clear

preserve
collapse (mean) logHHIfm = ln_hhi (sum) Hire, by(year pcs fuaX)
sort year pcs fuaX
tempfile tempfm
save `tempfm', replace
restore

use "data_for_regressions_`minyear'_`maxyear'_cvrfuaX.dta", clear

collapse (mean) logHHIf = ln_hhi (sum) Hire, by(year pcs fuaX)
merge 1:1 year pcs fuaX using `tempfm'

label var logHHIf "log HHI (based on firm identifiers)"
label var logHHIfm "log HHI (based on firmXmunicipality identifiers)"

twoway scatter logHHIfm logHHIf, msize(tiny) title(Denmark) /* note("The graph shows the relationship between two indices of labour-market concentration at the occupation-year-local labour market level") */
reg logHHIfm logHHIf [pw = Hire]
graph save "HHI\Figures\HHIfmHHIf_Denmark", replace
graph export "HHI\Figures\HHIfmHHIf_Denmark.png", replace


************ TABLE 1.1 ************

use "data_for_regressions_`minyear'_`maxyear'_komcvrfuaX.dta", clear

winsor2 smal_timeloen, cuts(1 99) trim
replace ln_hourly_wage = ln(smal_timeloen_tr)

gen daily_wage = exp(ln_daily_wage)
winsor2 daily_wage, cuts(1 99) trim
replace ln_daily_wage = ln(daily_wage_tr)

global fixed = "id occ#geo firm#munic#year firm#nic aldernov_n"

ivreghdfe ln_hourly_wage full_time Hire emp_prev_year (ln_hhi = IV_mH), absorb($fixed) cluster(cluster)

keep if e(sample)

gen hhi = exp(ln_hhi)

sum hhi
sum hhi if Hire

replace daily_wage_tr = daily_wage_tr / 7.44
sum daily_wage_tr if full_time
sum daily_wage_tr if Hire & full_time

replace smal_timeloen_tr = smal_timeloen_tr / 7.44

sum smal_timeloen_tr if full_time
sum smal_timeloen_tr if Hire & full_time

sum smal_timeloen_tr
sum smal_timeloen_tr if Hire

gen Woman = (kon_n == 2)
sum Woman
sum Woman if Hire

sum aldernov_n
sum aldernov_n if Hire

sort year pnr
merge m:1 year pnr using "Education Categories.dta"

drop if _merge == 2
drop _merge

gen educ_cat_new = educ_cat
drop educ_cat
tab educ_cat_new, missing

sort pnr
merge m:1 pnr using "Education Categories_sorted by pnr.dta"
drop if _merge == 2
drop _merge

replace educ_cat_new = educ_cat if educ_cat_new == .
drop educ_cat

rename educ_cat_new educ_cat

tab educ_cat, missing g(educ_cat_)
sum educ_cat_*
drop educ_cat_*
tab educ_cat if Hire, missing g(educ_cat_)
sum educ_cat_*
drop educ_cat_*

sum full_time
sum full_time if Hire

sum Hire

sum emp_prev_year if Hire


************ AVERAGE NUMBER OF OCCUPATIONS PER FIRM-MUNICIPALITY ************

tempfile temp
save `temp', replace

global occ pcs
global sircom komcvr
global year year

*computing number of occupations at the firmXmunicipality-by-year level
preserve
ge one=1
collapse (count) one, by($occ $sircom $year)
duplicates tag $sircom $year, ge(numb_occ)
replace numb_occ=numb_occ+1
drop one
sort $occ $sircom $year
save numb_occ, replace

*calculating the mean over the distribution of individual observations
restore
sort $occ $sircom $year
merge m:1 $occ $sircom $year using numb_occ
drop if _m == 2
drop _m
sum numb_occ

*this is the mean 
disp "mean number of occupations: "r(mean)
disp "std number of occupations: " r(sd)

use `temp', clear

keep if Hire

global occ pcs
global sircom komcvr
global year year

*computing number of occupations at the firmXmunicipality-by-year level
preserve
ge one=1
collapse (count) one, by($occ $sircom $year)
duplicates tag $sircom $year, ge(numb_occ)
replace numb_occ=numb_occ+1
drop one
sort $occ $sircom $year
save numb_occ, replace

*calculating the mean over the distribution of individual observations
restore
sort $occ $sircom $year
merge m:1 $occ $sircom $year using numb_occ
drop if _m == 2
drop _m
sum numb_occ

*this is the mean (New Hires Only)
disp "mean number of occupations: "r(mean)
disp "std number of occupations: " r(sd)


************ TABLE 1.2 ************

*N/A


************ TABLE 2.1 ************

use "data_for_regressions_`minyear'_`maxyear'_komcvrfuaX.dta", clear

winsor2 smal_timeloen, cuts(1 99) trim
replace ln_hourly_wage = ln(smal_timeloen_tr)

gen daily_wage = exp(ln_daily_wage)
winsor2 daily_wage, cuts(1 99) trim
replace ln_daily_wage = ln(daily_wage_tr)

global fixed = "id occ#geo firm#munic#year firm#nic aldernov_n"

*DAILY WAGES

reghdfe ln_daily_wage ln_hhi Hire emp_prev_year if full_time, absorb($fixed) cluster(cluster)


************ TABLE 2.2 ************

use "data_for_regressions_`minyear'_`maxyear'_komcvrfuaX.dta", clear

winsor2 smal_timeloen, cuts(1 99) trim
replace ln_hourly_wage = ln(smal_timeloen_tr)

gen daily_wage = exp(ln_daily_wage)
winsor2 daily_wage, cuts(1 99) trim
replace ln_daily_wage = ln(daily_wage_tr)

global fixed = "id occ#geo firm#munic#year firm#nic aldernov_n"

*DAILY WAGES

ivreghdfe ln_daily_wage Hire emp_prev_year (ln_hhi = IV_mH) if full_time, absorb($fixed) cluster(cluster) first
preserve
keep if e(sample)
reghdfe ln_hhi IV_mH Hire emp_prev_year if full_time, absorb($fixed) cluster(cluster)
restore

************ TABLE 2.3 ***************

use "data_for_regressions_`minyear'_`maxyear'_komcvrfuaX.dta", clear

winsor2 smal_timeloen, cuts(1 99) trim
replace ln_hourly_wage = ln(smal_timeloen_tr)

gen daily_wage = exp(ln_daily_wage)
winsor2 daily_wage, cuts(1 99) trim
replace ln_daily_wage = ln(daily_wage_tr)

global fixed = "id occ#geo firm#munic#year firm#nic aldernov_n"

*DAILY WAGES

ivreghdfe ln_daily_wage Hire emp_prev_year (ln_hhi = IV_S) if full_time, absorb($fixed) cluster(cluster) first
preserve
keep if e(sample)
reghdfe ln_hhi IV_S Hire emp_prev_year if full_time, absorb($fixed) cluster(cluster)
restore

************ TABLE 2.4 ************

use "data_for_regressions_`minyear'_`maxyear'_komcvrfuaX.dta", clear

winsor2 smal_timeloen, cuts(1 99) trim
replace ln_hourly_wage = ln(smal_timeloen_tr)

gen daily_wage = exp(ln_daily_wage)
winsor2 daily_wage, cuts(1 99) trim
replace ln_daily_wage = ln(daily_wage_tr)

global fixed = "id occ#geo firm#munic#year firm#nic aldernov_n"

*DAILY WAGES

ivreghdfe ln_daily_wage Hire emp_prev_year (ln_hhi_E = IV_mE) if full_time, absorb($fixed) cluster(cluster) first
preserve
keep if e(sample)
reghdfe ln_hhi_E IV_mE Hire emp_prev_year if full_time, absorb($fixed) cluster(cluster)
restore

************ TABLE 2.5 ************

use "data_for_regressions_`minyear'_`maxyear'_komcvrfuaX.dta", clear

preserve
collapse (sum) Hire, by(pcs year)
egen tot = sum(Hire), by(year)
gen shocc = Hire/tot
keep pcs year shocc
sort pcs year
tempfile shocc
save `shocc', replace
restore

sort pcs year
merge m:1 pcs year using `shocc'


winsor2 smal_timeloen, cuts(1 99) trim
replace ln_hourly_wage = ln(smal_timeloen_tr)

gen daily_wage = exp(ln_daily_wage)
winsor2 daily_wage, cuts(1 99) trim
replace ln_daily_wage = ln(daily_wage_tr)


global fixed = "id occ#geo firm#munic#year firm#nic aldernov_n"

*DAILY WAGES

ivreghdfe ln_daily_wage full_time Hire emp_prev_year shocc (ln_hhi = IV_mH) if full_time, absorb($fixed) cluster(cluster)


************ TABLE 2.6 ************

set more off

use "data_for_regressions_`minyear'_`maxyear'_komcvrfuaX.dta", clear

winsor2 smal_timeloen, cuts(1 99) trim
replace ln_hourly_wage = ln(smal_timeloen_tr)

gen daily_wage = exp(ln_daily_wage)
winsor2 daily_wage, cuts(1 99) trim
replace ln_daily_wage = ln(daily_wage_tr)

global Dvar ln_daily_wage
global LHHI ln_hhi
global IV IV_mH
global fixed id occ#geo firm#munic#year firm#nic aldernov_n full_time Hire emp_prev_year
global cluster cluster

*ssc install plausexog

reghdfe $Dvar $IV, abs($fixed) cluster($cluster)

global G = _b[$IV]
global seG = _se[$IV]

keep if $Dvar !=. & $LHHI != . & $IV != .
reghdfe $Dvar, abs($fixed) residuals(Dvar_e)
reghdfe $LHHI, abs($fixed) residuals(lhhi_e)
reghdfe $IV, abs($fixed) residuals(IV_e)

scalar max = 0
local n = 0
while `n' > $G {
	local n = `n' + ($G/30)
	disp in ye `n'
	*plausexog uci Dvar_e (lhhi_e = IV_e), gmin(`n') gmax(0) leveel(0.90) vce(cluster $cluster)
	*scalar_ub = e(ub_lhhi_e)
	ivregress 2sls Dvar_e (lhhi_e = IV_e), vce(cluster $cluster)
	scalar ub = _b[lhhi_e] + 1.64*_se[lhhi_e]
	scalar max1 = max
	scalar max = `n'
	if ub > 0 {
		local n = $G - 1
		
	}
	
}

disp ub
disp max1

gen Y1 = .
local n = max1 
while `n' < 0 {
	disp "gamma =" `n'
	replace Y1 = $Dvar - ($IV*`n')
	ivreghdfe Y1 ($LHHI = $IV), abs($fixed) level(90) cluster($cluster)
	scalar ub = _b[$LHHI] + 1.64*_se[$LHHI]
	scalar gmin = `n'
	disp gmin
	if ub < 0 {
		local n = 1
	}
	local n = `n' - ($G/30)
}

disp "reduced form gamma = " $G
disp "standard error of reduced form gamma = " $seG
disp "min gamma = " gmin


************ TABLE 2.7 ************

*N/A


************ TABLE 2.8 ************

use "data_for_regressions_`minyear'_`maxyear'_cvrfuaX.dta", clear

winsor2 smal_timeloen, cuts(1 99) trim
replace ln_hourly_wage = ln(smal_timeloen_tr)

gen daily_wage = exp(ln_daily_wage)
winsor2 daily_wage, cuts(1 99) trim
replace ln_daily_wage = ln(daily_wage_tr)

global fixed = "id occ#geo firm#munic#year firm#nic aldernov_n"

*DAILY WAGES

ivreghdfe ln_daily_wage  full_time Hire emp_prev_year (ln_hhi = IV_mH) if full_time, absorb($fixed) cluster(cluster)


************ TABLE 2.9 ************

use "data_for_regressions_`minyear'_`maxyear'_komcvrfuaX_DISCO2.dta", clear

winsor2 smal_timeloen, cuts(1 99) trim
replace ln_hourly_wage = ln(smal_timeloen_tr)

gen daily_wage = exp(ln_daily_wage)
winsor2 daily_wage, cuts(1 99) trim
replace ln_daily_wage = ln(daily_wage_tr)


global fixed = "id occ#geo firm#munic#year firm#nic aldernov_n"

*DAILY WAGES

ivreghdfe ln_daily_wage Hire emp_prev_year (ln_hhi = IV_mH) if full_time, absorb($fixed) cluster(cluster) first
preserve
keep if e(sample)
reghdfe ln_hhi IV_mH Hire emp_prev_year if full_time, absorb($fixed) cluster(cluster)
restore


************ TABLE 2.10 ************

use "data_for_regressions_`minyear'_`maxyear'_komcvrfuaX.dta", clear
tostring year, replace

sort year fuaX pcs
merge m:1 year fuaX pcs using "ArnoldHHI.dta"
drop if _merge == 2
drop _merge

gen ln_HHI_A = ln(HHI_A)
gen ln_HHI_a = ln(HHI_a)
gen ln_HHI_H = ln(HHI_H)

destring year, replace

winsor2 smal_timeloen, cuts(1 99) trim
replace ln_hourly_wage = ln(smal_timeloen_tr)

gen daily_wage = exp(ln_daily_wage)
winsor2 daily_wage, cuts(1 99) trim
replace ln_daily_wage = ln(daily_wage_tr)

global fixed = "id occ#geo firm#munic#year firm#nic aldernov_n"

*DAILY WAGES

ivreghdfe ln_daily_wage Hire emp_prev_year (ln_HHI_A = IV_mE) if full_time, absorb($fixed) cluster(cluster) first
ivreghdfe ln_daily_wage Hire emp_prev_year (ln_HHI_H = IV_mE) if full_time, absorb($fixed) cluster(cluster) first
ivreghdfe ln_daily_wage Hire emp_prev_year (ln_hhi_E = IV_mE) if full_time & e(sample), absorb($fixed) cluster(cluster) first
preserve
keep if e(sample)
reghdfe ln_HHI_A IV_mH Hire emp_prev_year if full_time, absorb($fixed) cluster(cluster)
restore

************ TABLE 2.11 ************

use "data_for_regressions_`minyear'_`maxyear'_komcvrfua1.dta", clear

winsor2 smal_timeloen, cuts(1 99) trim
replace ln_hourly_wage = ln(smal_timeloen_tr)

gen daily_wage = exp(ln_daily_wage)
winsor2 daily_wage, cuts(1 99) trim
replace ln_daily_wage = ln(daily_wage_tr)

global fixed = "id occ#geo firm#munic#year firm#nic aldernov_n"

*DAILY WAGES

ivreghdfe ln_daily_wage  full_time Hire emp_prev_year (ln_hhi = IV_mH) if full_time, absorb($fixed) cluster(cluster)


************ TABLE 2.12 ************

use "data_for_regressions_`minyear'_`maxyear'_komcvrdep.dta", clear

winsor2 smal_timeloen, cuts(1 99) trim
replace ln_hourly_wage = ln(smal_timeloen_tr)

gen daily_wage = exp(ln_daily_wage)
winsor2 daily_wage, cuts(1 99) trim
replace ln_daily_wage = ln(daily_wage_tr)

global fixed = "id occ#geo firm#munic#year firm#nic aldernov_n"

*DAILY WAGES

ivreghdfe ln_daily_wage Hire emp_prev_year (ln_hhi = IV_mH) if full_time, absorb($fixed) cluster(cluster) first
preserve
keep if e(sample)
reghdfe ln_hhi IV_mH Hire emp_prev_year if full_time, absorb($fixed) cluster(cluster)
restore


************ TABLE 2.13 ************

*N/A

************ TABLE 2.14 ************

*N/A

************ TABLE 2.15 ************

*N/A

************ TABLE 2.16 ************

*N/A

************ TABLE 2.17 ************

*N/A

************ TABLE 2.18 ************

*N/A

************ TABLE 2.19 ************

*N/A

************ TABLE 2.20 ************

*N/A

************ TABLE 2.21 ************

*N/A

************ TABLE 2.22 ************

*N/A

************ TABLE 2.23 ************

*N/A

************ TABLE 2.24 ************

*N/A

************ TABLE 2.25 ************

*N/A

************ TABLE 2.26 ************

*N/A

************ TABLE 2.27 ************

*N/A

************ TABLE 2.28 ************

*N/A

************ TABLE 2.29 ************

*N/A

************ TABLE 2.30 ************

*N/A

************ TABLE 2.31 ************

*N/A

************ TABLE 2.32 ************

*N/A


log close

exit