clear
cap log c
log using WageRegressionBaseline.log, replace

*BASELINE WAGE REGRESSIONS 4-DIGIT OCCUPATIONS (Tables 2; 4; 2.1; 2.2; 2.7; 2.8; 2.11; 2.12)  
*BASELINE: FUNCTIONAL AREAS (fuaX), firmXmunicipality (sircomt) and full-time daily wages (dwage)
* ALL OTHER WAGE TYPES (only fuaX only IV only sircomt)
* OTHER TYPES OF GEO AREA: NUTS3 (dep) AND FUAs (fua1) (only IV only sircomt only dwage)
* OTHER TYPES OF EMPLOYER IDENTIFIERS (only fuaX only dwage only IV)


local aggregateL  sircomt siren sirepci sirlau1
local zoneL  fuaX dep fua1   

foreach zone of loc zoneL {	
	foreach y of loc aggregateL {	
	foreach var in  dwage  wage wageft  {	
	
	* running condition (to estimate only necessary regressions - saving time)
	if ("`var'"=="dwage"&"`zone'"=="fuaX"&"`y'"=="sircomt")|("`var'"=="dwage"&"`zone'"=="fuaX"&"`y'"!="sircomt")|("`var'"=="dwage"&"`zone'"!="fuaX"&"`y'"=="sircomt")|("`var'"!="dwage"&"`zone'"=="fuaX"&"`y'"=="sircomt") {
					* load data
					use prewage, clear
					* drop useless vars
					drop ce entsir ancsir
					
					*constructing hourly wages for fulltimers
					ge wageft = wage if ftpt==1

					disp "XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX"
					disp "`var' HHI1 `zone' `y'" 
					disp "XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX"
					
					* limiting sample where necessary
					if "`var'"=="dwage"|"`var'"=="wageft" {
						keep if ftpt==1
					}
					
					* merging with appropriate presence/absence indicators the year before
					if "`y'"=="siren" {
						sort nninouv sir an
						merge 1:1 nninouv sir an using P1siren
						drop if _m==2
						drop _m
					}
					if "`y'"=="sircomt" {
						sort nninouv sircom sir an
						merge 1:1 nninouv sircom sir an using P1sircom
						drop if _m==2
						drop _m
					}
					if "`y'"=="sirepci" {
						sort nninouv sirepci sir an
						merge 1:1 nninouv sirepci sir an using P1sirepci
						drop if _m==2
						drop _m
					}
					if "`y'"=="sirlau1" {
						sort nninouv sirlau1 sir an
						merge 1:1 nninouv sirlau1 sir an using P1sirlau1
						drop if _m==2
						drop _m
					}
					
					drop P1m
					sort nninouv an
					merge m:1 nninouv an using P1
					drop if _m==2
					drop _m

					* new hire and employed the year before indicators
					ge Hire=(P1ysir!=1)
					ge Emp1y=(Hire*P1y==1)
					drop P1*
					
					* merging with HHI data
					sort `zone' pcs year			
					merge m:1 `zone' pcs year using HHI\HHI1_HP`y'`zone'_pcs41	
					keep if _m==3
					drop _m	
					*creating logs
					ge logShare_E=log(Share_E)
					
					*merging with instruments
					merge m:1 `zone' pcs year using HHI_IV\FIN_HHI1_HP`y'`zone'_pcs41	
					drop if _m==2
					drop _m
					ren IV_S IV_HHI
					
					compress
					
					* loading correct cluster variable
					if "`zone'"=="dep" {
						replace geo=nuts
						replace cluster=cluster2
					}
						if "`zone'"=="fua1" {
						replace geo=fua1_n
						replace cluster=cluster3
					}		



*defining fixed effects
global fixed = "id occ#geo firm#mun#an firm#nic age ftpt Hire Emp1y "
	if "`y'"=="sirepci" {
	global fixed = "id occ#geo firm#epci_n#an firm#nic age ftpt Hire Emp1y "
	}
	if "`y'"=="sirlau1" {
	global fixed = "id occ#geo firm#lau1_n#an firm#nic age ftpt Hire Emp1y "
	}	

if "`var'"=="dwage"&"`zone'"=="fuaX"&"`y'"=="sircomt" {	
	disp "First stage `var' MODEL 1"	
	reghdfe  logShare_E IV_mH if `var'!=., absorb($fixed)  cluster(cluster) 	
	disp "`var'  MODEL 1"
	disp "OLS"
	reghdfe `var' logShare_E, absorb($fixed)  cluster(cluster) 	
	}

disp "`var'  MODEL 1"
disp "IV"
ivreghdfe `var' (logShare_E=IV_mH), absorb($fixed)  cluster(cluster) 


}	
}
}
}

cap log c
