

cd "C:\Users\Public\Documents\Europe"
set more off 
cap log c
log using tprob2&4.log, replace


*****************************************************
************* TRANSITION PROBABILITIES ********
*****************************************************


***** First step: create a database with variables for observations at t and at t-1 (to avoid tsetting)

** individuals one year ago
use PanelbaseFUA.dta, clear

destring year, ge(an)
replace an=an+1
drop if an==18

*** first condition: main job one year ago should be at least 30 days duration
ge dp2=dp
replace dp2=finremu-debremu+1 if dp==.
keep if dp2>=30

keep an sir sircom nninouv dp2 pcs nbheur netnet 

rename pcs pcs_1
rename dp2 dp2_1
rename nbheur nbheur_1
rename netnet netnet_1


keep if regexm(pcs,"^[0-9][0-9][0-9][A-Z]")
drop if mi(pcs)
sort nninouv sircom sir an
save indiv_originH, replace

*** construct a variable identifying those who remain in the firmXmunicipality the year after

use PanelbaseFUA.dta, clear

destring year, ge(an)
drop if an==9

ge dp2=dp
replace dp2=finremu-debremu+1 if dp==.
keep if dp2>=30

*keep industries
					keep if (substr(apet, 1, 2)>="05"&substr(apet, 1, 2)<="82")|substr(apet, 1, 2)=="90"| ///
						substr(apet, 1, 2)>="92"&substr(apet, 1, 2)<="96"

drop debremu finremu filtre s_brut contrat_travail apen2
drop age dp ce sx catjur domempl apet2 entsir ancsir ditot di416 educ epci LIBEPCI dep fua1 fuaX lau1 NAME_1 sirepci sirlau1
drop netnetr

* find new hires
sort nninouv sircom sir an
merge 1:1 nninouv sircom sir an using P1sircom
drop if _m==2
drop _m

					drop P1m
					sort nninouv an
					merge m:1 nninouv an using P1
					drop if _m==2
					drop _m

					ge Hire=(P1ysir!=1)
					ge Emp1y=(Hire*P1y==1)
					
keep if Hire==1					

* merging with records of the previous year					
sort nninouv an
merge 1:1 nninouv sircom sir an using indiv_originH
ren _m mergeorigin

save temp_tH, replace

*** second step: identifying the main job previous year among those with at least 30 days duration
* looping over years
foreach y of numlist 10/17 {
	use temp_tH, clear

	ge p1=1 



	keep if an==`y'

	* second condition: pick that with the same occupation, if there is any
	ge occorigin=""
	levelsof pcs_1, local(pcs)

	foreach p of local pcs {
		disp `y' "  `p'"
		ge p1_`p'=(pcs_1=="`p'")
		egen maxp1_`p'=max(p1_`p'), by(nninouv)
		replace occorigin="`p'" if pcs=="`p'"&maxp1_`p'==1
		drop p1_`p' maxp1_`p'
	}
	
	* indicators for max duration, max hours and max salary
	egen maxdp=max(dp2_1), by(nninouv)	
	egen maxh=max(nbheur_1)	if abs(maxdp-dp2_1)<1, by(nninouv)
	egen maxw=max(netnet_1)	if abs(maxdp-dp2_1)<1&abs(maxh-nbheur_1)<1, by(nninouv)
	
	* third condition: pick the one with the longest duration, if there are no ties
	ge occmode=pcs_1 if abs(maxdp-dp2_1)<1&occorigin==""
	duplicates tag nninouv if occmode!="", ge(tag)
	duplicates tag nninouv occmode if occmode!="", ge(tag2)
	egen mode=mode(occmode) if tag==tag2, by(nninouv)
	replace occorigin=mode if occorigin==""
	drop mode occmode tag tag2

	* fourth condition: among the new ties, pick the one with the longest hours, if there are no new ties
	ge occmode=pcs_1 if abs(maxdp-dp2_1)<1&abs(maxh-nbheur_1)<1
	duplicates tag nninouv if occmode!="", ge(tag)
	duplicates tag nninouv occmode if occmode!="", ge(tag2)
	egen mode=mode(occmode) if tag==tag2, by(nninouv)
	replace occorigin=mode if occorigin==""
	drop mode occmode tag tag2
	
	* 	fifth condition: among the new ties, pick the one with the highest salary, if there are no new ties
	ge occmode=pcs_1 if abs(maxdp-dp2_1)<1&abs(maxh-nbheur_1)<1&abs(maxw-netnet_1)<1
	duplicates tag nninouv if occmode!="", ge(tag)
	duplicates tag nninouv occmode if occmode!="", ge(tag2)
	egen mode=mode(occmode) if tag==tag2, by(nninouv)
	replace occorigin=mode if occorigin==""
	drop mode occmode tag tag2
	
	* 	sixth condition: among the new ties, pick the one with the highest salary, if there are no new ties
	ge occmode=pcs_1 if abs(maxdp-dp2_1)<1&abs(maxh-nbheur_1)<1&abs(maxw-netnet_1)<1&occorigin==""
	egen mode=mode(occmode), by(nninouv)
	replace occorigin=mode if occorigin==""
	drop mode occmode

	* 	seventh condition: among the new ties, pick one at random
	set seed 1
	ge u=runiform()
	ge d=abs((_n/_N)-u)
	egen mind=min(d) if abs(maxdp-dp2_1)<1&abs(maxh-nbheur_1)<1&abs(maxw-netnet_1)<1&occorigin=="", by(nninouv)
	ge occmode=pcs_1 if abs(maxdp-dp2_1)<1&abs(maxh-nbheur_1)<1&abs(maxw-netnet_1)<1&abs(mind-d)<0.00000001&occorigin==""
	egen mode=mode(occmode), by(nninouv)
	replace occorigin=mode if occorigin==""
	drop mode occmode
	
	save temptemp, replace
	

	

	keep if pcs!=""
	keep if occorigin!=""
	
	save temp_tH`y', replace
	
}

* third step: squared occupation matrix
use HHI\HHI1_HPsircomtfuaX_pcs41, clear
collapse (sum) Z_E, by(pcs)
ge one=1
ren Z_E Z_E0
sort one
save pcs_list, replace
ren pcs occorigin
ren Z_E Z_E1
sort one
joinby one using pcs_list
keep pcs occorigin Z_E1 Z_E0
sort pcs occorigin
save pcs_squaredH, replace


*** fourth step: calculating transition probabilities

* computing transitions per year
clear
set obs 1
ge v1=.
save tprobY, replace

foreach y of numlist 10/17 {
	use temp_tH`y', clear
	collapse (sum) p1, by(occorigin pcs)
	replace p1=0 if p1==.
	ge year="20`y'"
	save tprob`y', replace
	append using tprobY
	save tprobY, replace

	
}

drop if p1==.

* computing average transitions
collapse (sum) p1, by(pcs occorigin)
sort pcs occorigin
	merge 1:1 pcs occorigin using pcs_squaredH
	drop if _m==1
	replace p1=0 if p1==.

	
	drop  _m
	sort pcs
	compress
save tprobY, replace	

* computing final statistic 	
ge same2=(substr(pcs,1,2)==substr(occorigin,1,2))
ge same4=(pcs==occorigin)
ge trans2=p1*same2
ge trans4=p1*same4
ge occ2=substr(occorigin,1,2)
collapse (sum) trans2 trans4 p1, by(occ2)
ge ratio=trans4/trans2

sum ratio [aw=p1] // THIS IS THE PERCENTAGE REPORTED IN THE PAPER

