********************************************************************************
* Title: 00. Run all dofiles.do
* Description: This dofile runs all the necessary codes to reproduce the results
* for Spain.
********************************************************************************

	clear all
	cap log close
	macro drop _all 
		
********************************************************************************
* A. Set directories
********************************************************************************

		global path 					"[INSERT MAIN PATH]"					// Main path
			global input 				"$path\dta"								// Where intermediate data is located. Please, create folder
			global dofiles 				"$path" 								// Where dofiles are located
			global output 				"$path\out" 							// Where descriptives and tables are located. Please, create folder
			global hhi 					"$path\dta" 							// Where HHI estimates are located
			global logs 				"$path\log" 							// Where logs are located. Please, create folder	
			global intermediate_files 	"$path\dta\intermediate_files"			// Where intermediate files are located. Please, create folder
			global raw 					"$path\raw"								// Where excel files are located
			
		global raw_contracts 			"[INSERT PATH OF CONTRACTS]"			// Where contracts data is located
		
********************************************************************************
* B. Dofiles directory selection
********************************************************************************
	
	global d01 	= 0 // Generate the FUAs dataset
	global d02 	= 0 // Prepare the data
	global d03 	= 0 // Generate a unique masters dataset at year level
	global d04a = 0 // Estimate HHIs at Firm level
	global d04b = 0 // Estimate IVs for the regressions
	global d04c = 0 // Estimate the share of occupations	
	global d05 	= 0 // Main regressions
	global d06 	= 0 // Robustness checks
		global rob1 = 0 // Firm level
		global rob2 = 0 // Interactions by age and gender
		global rob3 = 0	// At FUA and NUTS-3
		global rob4 = 0 // With the share of occupations
		global rob5 = 0 // Exogeneity of the regressors
		global rob6 = 0 // HHIs at 2-digit level
		global rob7 = 0 // Alternative IV with leave-one-out HHI
		global rob8 = 0 // Interactions by nationality
		global rob9 = 0 // Interactions by education
	global d07 = 0 // Descriptive statistics	
	
********************************************************************************
* C. Decision selections
********************************************************************************

	global sample_size 	 = 15 	// 15% random sample of workers
	global random_sample = 1 	// We run regressions on a 15 % random sample of workers ($sample_size) 
	
********************************************************************************
* D. Run selected dofiles
********************************************************************************

	if $d01 == 1 {
	do "$dofiles\01. Generate FuaX.do"
	}

	if $d02 == 1 {
	do "$dofiles\02. Load contracts data.do"
	}

	if $d03 == 1 {
	do "$dofiles\03. Consolidate contracts data.do"
	}
	
	if $d04a == 1 {
	do "$dofiles\04.a Estimate hhi.do"
	}
		
	if $d04b == 1 {
	do "$dofiles\04.b Estimate iv.do"
	}

	if $d04c == 1 {
	do "$dofiles\04.c Estimate occupation shares.do"
	}		
	
	if $d05 == 1 {
	do "$dofiles\05. Regression analysis.do"
	}
	
	if $d06 == 1 {
	do "$dofiles\06. Robustness analysis.do"
	}
	
	if $d07 == 1 {
	do "$dofiles\07. Descriptives.do"
	}
	
************************ END OF DOFILE *****************************************
	cap log close
	exit,clear
