********************************************************************************
* Title: 01. Generate FuaX.do
* Description: This dofile creates the FuaX map correspondence.
********************************************************************************
	
	clear
	set trace off
	global date: di %tdCYND daily("$S_DATE", "DMY")

********************************************************************************
* A. Log
********************************************************************************

	cap log close
	cap log using "$logs\01. Generate FuaX $date.log",replace

********************************************************************************
* B. Load list of FUAs
********************************************************************************

	import excel "$raw\list-of-municipalities-in-functional-urban-areas.xls", first clear sheet("list_mun") cellrange(A1:H35008)
		
		keep if Country == "Spain"
		
		ren (CODEoffunctionalurbanarea CORE1 Nameoffunctionalurbanarea) /// 
			(fua core fua_name)
		
		gen municipio_cc = real(substr(IDMunicipality, 3, .))
		
		keep fua core municipio_cc fua_name
		
		tempfile fuas
		save `fuas', replace

********************************************************************************
* C. Load municipalities
********************************************************************************

	import excel "$raw\EU-28_2015.xlsx", sheet("ES") cellrange(A1:E8120) first clear

		ren (NUTS_3 LAU2_NAT_CODE NAME_1) (nuts_3 municipio_cc municipio_name)
		keep nuts_3 municipio_cc municipio_name

		destring *, replace

********************************************************************************
* D. Combine and create FuaX
********************************************************************************		

	* Match with list of municipalities
	*---------------------------------------------------------------------------
	merge 1:1 municipio_cc using `fuas'
	drop if _merge==2

	gen d1=1
	gen d2=(_merge==3)
	gen d3=(_merge==1)

	bys nuts_3: egen total_merged=sum(d2)
	gen has_one=(total_merged>0)

	bys nuts_3: egen total=sum(d1)
	bys nuts_3: egen total_nomerged=sum(d3)

	gen ratio=total_nomerged/total
	
	* Define FUAX as NUTS3
	gen fuax=nuts_3 if ratio>=0.7 & ratio<. & length(fua)==0
	replace fuax=fua if missing(fuax)

	ren (municipio_cc municipio_name) (MUNICIPIO_CC MUNICIPIO_NAME)
	
	* Save
	*---------------------------------------------------------------------------
	keep nuts_3 MUNICIPIO_CC MUNICIPIO_NAME fua fuax 
	
	label var nuts_3 		 "NUTS3"
	label var MUNICIPIO_CC 	 "Municipality"
	label var MUNICIPIO_NAME "Municipality name"
	label var fua			 "Functional Urban Area"
	label var fuax			 "FUA+NUTS3"
	
	sort MUNICIPIO_CC
	save "$input\maps\FuaX maps.dta",replace	
	
************************ END OF DOFILE *****************************************
	cap log close
	exit,clear
