********************************************************************************
* Title: 04.a Estimate hhi.do
* Description: This dofile dofile estimates the corresponding HHIs.
********************************************************************************
	
	clear
	set trace off
	global date: di %tdCYND daily("$S_DATE", "DMY")

********************************************************************************
* B. Log
********************************************************************************

	cap log close
	cap log using "$logs\04.a Estimate hhi $date.log",replace

********************************************************************************
* C. Estimate the HHIs at Firm level
********************************************************************************
	
	cd "$input"
	use "collapse_by_year.dta",clear
	
	// Drop if time employed <30 days
	drop if DATE_END-DATE_BEGIN<30

	// Exclude some sectors
	*NACE 05-82, arts (90), entertainment (92), recreation (93), associations (94), 
	*repair (95) and personal services including hairdressing or laundries (96). 
	*We exclude self-employed and household employees.

	destring CNAE_CC,replace
	keep if inrange(CNAE_CC,5,82)|CNAE_CC==90|CNAE_CC==92|CNAE_CC==93|CNAE_CC==94|CNAE_CC==95|CNAE_CC==96	
	
	forval x=1/2 {
		forval y=1/3 {

			cap drop s total

			cap drop dup

			bys market`x'_`y' j year: egen s=sum(one)

			bys market`x'_`y' year : egen total=sum(one)

			bys market`x'_`y' j year :gen dup=_n

			replace s=. if dup>1

			replace s=((s/total))^2

			cap drop hhi_`x'_`y'

			bys market`x'_`y' year : egen hhi_`x'_`y'=sum(s)

			replace hhi_`x'_`y'=. if market`x'_`y'==.

			gen dtotal_`x'_`y'=total

			cap drop s total

			}
	}
	
	*Save files
	cd "$hhi"
	forval x=1/2 {
		forval y=1/3 {
		
		preserve

			if `x'==1 {
				global add OCUP
			}

			if `x' == 2 {
				global add OCUP_2D
			}			

			keep hhi_`x'_`y' prov dtotal_`x'_`y' $add  fua`y' market`x'_`y' year

			drop if missing(hhi_`x'_`y')

			sort market`x'_`y' year
			
			gen dyear_`x'_`y' = dtotal_`x'_`y'
			
			cd "$hhi"
			
			save hhi_`x'_`y',replace

			keep market`x'_`y' $add  fua`y' prov dtotal_`x'_`y'

			duplicates drop market`x'_`y',force

			expand 8 ///  (2017-2010+1)

			bys market`x'_`y': gen n=_n-1

			gen year = 2010

			replace year = year + n

			drop n

			sort market`x'_`y' year

			merge market`x'_`y' year using hhi_`x'_`y'

			drop if _merge==2

			drop _merge

			sort market`x'_`y' year

			cd "$hhi"

			*Save the HHIs for all LLM and Years combination

			save hhi_`x'_`y',replace

		restore

		}
	}	

	cd "$hhi"

	forval x=1/2 {
		forval y=1/3 {
			use hhi_`x'_`y',clear
		
				keep hhi_`x'_`y' dyear_`x'_`y' dtotal_`x'_`y' market`x'_`y' year
				
				collapse (min) hhi_`x'_`y' dyear_`x'_`y' dtotal_`x'_`y' ,by(market`x'_`y' year)
				
				sort market`x'_`y' year
			
			save hhi_`x'_`y'_byear,replace	
		}
	}
	
********************************************************************************
* D. Estimate the HHIs Firm x Municipality
********************************************************************************

	cd "$input"

	use collapse_by_year,clear
	
	// Drop if time employed <30 days

	drop if DATE_END-DATE_BEGIN<30

	// Exclude some sectors
	*NACE 05-82, arts (90), entertainment (92), recreation (93), associations (94), 
	*repair (95) and personal services including hairdressing or laundries (96). 
	*We exclude self-employed and household employees.

	destring CNAE_CC,replace

	keep if inrange(CNAE_CC,5,82)|CNAE_CC==90|CNAE_CC==92|CNAE_CC==93|CNAE_CC==94|CNAE_CC==95|CNAE_CC==96	
	
	forval x=1/2 {
		forval y=1/3 {

			cap drop s total

			cap drop dup

			bys market`x'_`y' IDENT_CC year : egen s=sum(one_cc2)

			bys market`x'_`y' year : egen total=sum(one_cc2)

			bys market`x'_`y' IDENT_CC year :gen dup=_n

			replace s=. if dup>1

			replace s=((s/total))^2

			cap drop hhi_`x'_`y'

			bys market`x'_`y' year : egen hhi_`x'_`y'=sum(s)

			replace hhi_`x'_`y'=. if market`x'_`y'==.

			gen dtotal_`x'_`y'=total

			cap drop s total
		}
	}


*Save files
	cd "$hhi"
	forval x=1/2 {
		forval y=1/3 {
			
			preserve

				if `x'==1 {
					global add OCUP
				}

				if `x'==2 {
					global add OCUP_2D
				}			

				keep hhi_`x'_`y' prov dtotal_`x'_`y' $add  fua`y' market`x'_`y' year 

				drop if missing(hhi_`x'_`y')
			
				gen dyear_`x'_`y' = dtotal_`x'_`y'
			
				sort market`x'_`y' year

				cd "$hhi"

				compress

				save hhi_cc2_`x'_`y',replace

				keep market`x'_`y' $add  fua`y' prov dtotal_`x'_`y'

				duplicates drop market`x'_`y',force

				expand 8 ///  (2017-2010+1)

				bys market`x'_`y': gen n=_n-1

				gen year = 2010

				replace year = year + n

				drop n

				cd "$hhi"

				sort market`x'_`y' year

				merge market`x'_`y' year using hhi_cc2_`x'_`y'

				drop if _merge==2

				drop _merge

				sort market`x'_`y' year

				cd "$hhi"

				save hhi_cc2_`x'_`y',replace

			restore

		}
	}

	cd "$hhi"
	
	forval x=1/2 {
		forval y=1/3 {
			use hhi_cc2_`x'_`y',clear
			
			keep hhi_`x'_`y' dyear_`x'_`y' dtotal_`x'_`y' market`x'_`y' year
			
			collapse (min) dyear_`x'_`y' hhi_`x'_`y' dtotal_`x'_`y' ,by(market`x'_`y' year)
			
			sort market`x'_`y' year
			
			save hhi_cc2_`x'_`y'_byear,replace
		}
	}		
	
************************ END OF DOFILE *****************************************
	cap log close
	exit,clear
