********************************************************************************
* Title: 07. Descriptives.do
* Description: This dofile prepares the descriptives shown.
********************************************************************************
	
	clear
	set trace off
	global date: di %tdCYND daily("$S_DATE", "DMY")

********************************************************************************
* A. Generate log
********************************************************************************
	
	global date: di %tdCYND daily("$S_DATE", "DMY")

	cap log close
	cap log using "$logs\07. Descriptives $date.log",replace

********************************************************************************
* B. Prepare dataset
********************************************************************************	

	// Year level
		
		*** Correspondence
		use "$intermediate_files\market1_1_correspondence.dta",clear
		
		sort market1_1
		
		tempfile corr
		save `corr',replace
		
		*** HHI at Firm X Year level	
		use "$hhi\hhi_1_1_byear",clear	
		
		rename (hhi_1_1 dtotal_1_1) (firm_hhi firm_hires)
		
		tempfile firm_hhi
		save `firm_hhi',replace
		
	// FirmXMuni X year level
	use "$hhi\hhi_cc2_1_1_byear",clear
	
		*** With correspondence
		sort market1_1
		
		merge m:1 market1_1 using `corr',nogen keep(3)

		*** Match with Firm HHI
		sort market1_1 year
		merge 1:1 market1_1 year using `firm_hhi',keep(3) nogen	
		
		rename (hhi_1_1 dtotal_1_1) (fmuni_hhi fmuni_hires)
		
	// Generate log transformations
	foreach var in firm fmuni {
		gen l`var'_hhi=log(`var'_hhi)
	}
	
********************************************************************************
* C. Statistics about the HHI at Firm x Municipality (Table 1)
********************************************************************************			

	sum fmuni_hhi [w=fmuni_hires] if fmuni_hhi !=0 & fmuni_hhi !=. , detail

********************************************************************************
* D. Statistics about the HHI at Firm (Footnote 53)
********************************************************************************		

	sum firm_hhi [w=firm_hires] if firm_hhi != 0 & firm_hhi !=., detail

********************************************************************************
* E. Figures of HHI correspondence in Firm and FirmXMunicipality (Footnote 52)
********************************************************************************		

	label var lfirm_hhi "log HHI (based on firm identifiers)"
	label var lfmuni_hhi "log HHI (based on firmXmunicipality identifiers)"
	twoway scatter lfmuni_hhi lfirm_hhi, msize(tiny) title("Spain")
	graph export "$output\Figure 1.1.png", as(png) replace
	regr lfmuni_hhi lfirm_hhi [pw=firm_hires]

********************************************************************************
* F. Summary of regression analysis variables
********************************************************************************
	
	use "$input/data_sample",clear	

	// Merge HHIs
		cap drop _merge
		sort market1_1 year
		merge m:1 market1_1 year using "$hhi/hhi_cc2_1_1_byear",replace update
		keep if _merge==1|_merge==3|_merge==4|_merge==5
		
		rename hhi_1_1 hhi_cc2_1_1
		
		cap drop _merge

		gen lhhi_fua1=log(hhi_cc2_1_1)	

	// Run regressions
		keep if y_1!=.|y_2!=.	
	
	* Stability
		reg y_1 lhhi_fua1 i.women i.education i.dum_fix_t_1 i.FTPT cluster1 year age firmXmunXyear market1_1
		gen sample=e(sample)
		
		global stats="hhi_cc2_1_1 women age FTPT d_educ* dum_fix_t_1 y_1 y_2"
		
		estpost summarize $stats if sample== 1
		
		cd "$output"
		esttab using "Table 1.1.tex", tex cells("mean sd") mtitle("Mean" "SD") nonumber l varwidth(40) replace	

********************************************************************************
* G. Share of permanent new hires in the lowest decile of the HHI distribution
********************************************************************************		
	
	keep if sample == 1
	
	sum lhhi_fua1, detail
	ge HHIp10=(lhhi_fua1<=r(p10)&lhhi_fua1!=.)
	sum y_1 if HHIp10==1

	* this is the mean share of perm contracts
	disp "mean share perm contracts: " r(mean)
	disp "std share perm contracts: " r(sd)	
	
********************************************************************************
* H. Number of occupations per firmXmunicipality
********************************************************************************		

	* Names of variables as indicated
	global occ OCUP // Occupation variable
	global sircom IDENT_CC // FirmXmunicipality identifier
	global year year // Year variable

	* Computing number of occupations at the firmXmunicipality-by-year level
	preserve
		cap drop one
		ge one=1
		collapse (count) one, by($occ $sircom $year)
		duplicates tag $sircom $year, ge(numb_occ) 
		replace numb_occ=numb_occ+1
		drop one
		sort $occ $sircom $year
		save numb_occ, replace
	restore
	
	* Calculating the mean over the distribution of individual observation
	sort $occ $sircom $year
	merge m:1 $occ $sircom $year using numb_occ
	drop if _m==2
	drop _m
	sum numb_occ

	* Mean
	disp "mean number of occupations: " r(mean)
	disp "std number of occupations: " r(sd)

************************ END OF THIS DOFILE ************************************
clear
cap log close
exit,clear
