******************************************************************************************
*
*			
*		do-file:
*					Extracting and merging firm, establishment and worker-level datasets from Quadros de Pessoal (2010 to 2019)
*			
*					IMPORTANT!: change path in line 21 to the one where the raw Quadros de Pessoal datasets are located
*					otherwise the code will not run 
*
******************************************************************************************

clear all
set more off
cap log c


log using ../log/quadrospessoal_extract.log, replace



local pathQP "C:/Posto.Investigador//Microdados/Quadros de Pessoal/STATA"


* Creating variable to know details of worker-employee link from previous year

gen ano=6666
save ../dta/QPpanel, replace	
clear

foreach x of numlist 2010/2019{
dis "`x'"
		local y=substr("`x'",3,2)
		
		* FIRMS
		use "`pathQP'/empresas_`x'.dta", clear
		rename *, lower

			rename caemp caemp5d_r3	// 5 digit industry
			rename caem4 caemp4d_r3	// 4 digit industry
			rename caem3 caemp3d_r3 	// 3 digit industry
			rename caem2 caemp2d_r3 	// 2 digit industry
			rename caem1l caemp1L_r3 	// 1 letter industry		
			rename nut1_emp n1emp   // NUTS I
			rename nut2_emp n2emp  // NUTS II
			rename nut3_emp n3emp  // NUTS III
		
		tempfile emps
		save `emps', replace
		
		* ESTABLISHMENTS
		use "`pathQP'/estabelecimentos_`x'.dta", clear
		rename *, lower
		
			rename caest caest5d_r3 // renaming of industries as above
			rename caest4 caest4d_r3
			rename caest3 caest3d_r3
			rename caest2 caest2d_r3
			rename caest1l caest1L_r3	
			
			rename nut1_est n1est
			rename nut2_est n2est
			rename nut3_est n3est
		
		tempfile estabs
		save `estabs', replace
		
		* WORKERS
		use "`pathQP'/trabalhadores_`x'.dta", clear
		rename *, lower
			
			rename prof		prof5d_cpp10	// 5 digit occupation
			rename prof_4d	prof4d_cpp10	// 4 digit occupation
			rename prof_3d	prof3d_cpp10	// 3 digit occupation
			rename prof_2d	prof2d_cpp10	// 2 digit occupation
			rename prof_1d	prof1d_cpp10	// 1 digit occupation
			
			gen dtnas=ym(year(dt_nasc),month(dt_nasc))	// date of birth - transform  date format 
			drop dt_nasc 			
			gen dtadm=ym(year(dt_adm),month(dt_adm)) 	// date of entry in the firm - transform date format 
			drop dt_adm 			
			gen dtulp=ym(year(dt_prom),month(dt_prom))	// date of last promotion - transform date format 
			drop dtulp
			
			rename irct irc							// rename variable with the Collective Bargaining code
			rename ctpro catprof					// rename variable with the Collective Bargaining job title code
			rename sitpro sitprof					// rename variable with employment type (self-employed, not self-employed,...)
			gen portugues=nacio=="PT" if nacio!=""	// Create Nationality variable (Portuguese or Foreign)

		
		* Merge Firm, establishments and worker datasets for year `x'
			merge m:1 emp_id using `emps'
			keep if _m==3
			drop _m
			merge m:1 emp_id estab_id using `estabs'
			keep if _m==3
			drop _m
			
		rename (ntrab estab_id caemp2d_r3 caest2d_r3 prof4d_cpp10) (ident_s nic CAE2 CAEST2 pcs)
		
		* Generate firm identifier where all identifiers have the same lenght (by adding zeros in front of identifier)
		tostring emp_id, replace
		gen len=length(emp_id)
		sum len
		gen siren="0"*(`r(max)'-len)+emp_id
		drop len 
		drop emp_id
		drop fregemp fregest
		
		
		bysort ident_s siren nic ano: gen dup=_N // eliminating workers appearing twice in each October of each year (same firm, plant and worker)
		drop if dup>1
		drop dup 

		drop if ldest==9999  // dropping since muncipality 9999==Abroad. this is not of interest
		* Turning municipality's codes into strings with equal lenght (len=4)
		gen comt=ldest
		tostring comt, replace
		replace comt="0"+comt if length(comt)==3
		
		*generating indicator of presence in that year
		gen present=1
		
		compress
		
		* Build panel of Quadros de Pessoal from 2010 to 2019
		preserve
			append using  ../dta/QPpanel	
			drop if ano==6666
			compress
			save ../dta/QPpanel, replace	
		restore
		
		* Merge with Functional Areas data
		merge m:1 comt using ../dta/mergedMunicipalitiesFUAsPRT, gen(_mergefuas)
		drop if _mergefuas==2
		tab comt if _mergefuas==1
		drop _mergefuas
			
		* drop useless vars
		drop Nameoffunctionalurbanarea CORE1 mun_name fua0
		cap drop fua3 fua5 fua6 fua7 fua8 fua9 fua10
			
		* generate firmXmunicipality identifier
		gen sircomt=comt+siren
		compress
		save ../dta/QP/year`y'/FUAQP`y', replace
		
		
		
		* save dataset of QP lagged in one year
		ren * *_1	// renane all variables VAR_1 to indicate these are lagged
		
		* keep variable names that are important for merging purposes
		ren siren_1 siren
		ren sircomt_1 sircomt 
		
		ren nic_1 nic
		ren ident_s_1 ident_s
		gen ano=ano_1+1 // lag year variable
		compress
		save ../dta/QP/year`y'/FUAQP`y'_1, replace
}
	
log c