******************************************************************************************
*
*			
*		do-file:
*					this programme prepares the data that will be used in the regressions:
*
*  						I  - Data Assembly_________________________________________________lines 20 to 56
*  						II - Collective Barganing data_____________________________________lines 57 to 137
*  						III- Construction of variable for previous years___________________lines 138 to 193
*  						IV - Assembling final datasets for the regressions_________________lines 194 to 328
*							
******************************************************************************************

set more off
cap log c
log using ../log/mergefuaPanel.log, replace
**********************************************************************************************************
***************************************	I - DATA ASSEMBLY ************************************************
**********************************************************************************************************

use ../dta/QPpanel, clear
	
* for consistency with French code:
ren siren sir
ren ident_s nninouv
ren nic nic4
ren ano year
ren idade age
ren sexo sx
ren CAEST2 apet2

*drop non employees
keep if sitprof==3

keep if year>=2010

sort comt
merge m:1 comt using ../dta/mergedMunicipalitiesFUAsPRT, gen(_mergefuas)
drop if _mergefuas==2
tab comt if _mergefuas==1
drop _mergefuas

* drop useless vars
drop Nameoffunctionalurbanarea CORE1 mun_name fua0
cap drop fua3 fua5 fua6 fua7 fua8 fua9 fua10
drop fua4 fua2
		
* generate firmXmunicipality identifier
gen sircomt=comt+sir

*keep nbhors>0				
keep if hnormais>0

compress
save ../dta/PanelbaseFUA.dta, replace

cap log c
log using ../log/measure_colbarg.log, replace
**********************************************************************************************************
***************************************	II -  COLLECTIVE BARGANING DATA **************************************
**********************************************************************************************************

use ../dta/PanelbaseFUA.dta, clear

keep irc year sir nic4 apet2
compress

*Crosswalk, industry as in Germany

	gen apet2_coarse=.
	replace apet2_coarse=1  if  apet2>=1 & apet2<=3
	replace apet2_coarse=2  if (apet2>=5 & apet2<=9) | (apet2>=35 & apet2<=39)
	replace apet2_coarse=3  if  apet2>=10 & apet2<=12
	replace apet2_coarse=4  if  apet2>=13 & apet2<=18
	replace apet2_coarse=5  if  apet2>=19 & apet2<=24
	replace apet2_coarse=6  if  apet2>=25 & apet2<=33
	replace apet2_coarse=7  if  apet2>=41 & apet2<=43
	replace apet2_coarse=8  if  apet2>=45 & apet2<=46
	replace apet2_coarse=9  if  apet2==47
	replace apet2_coarse=10 if  apet2>=49 & apet2<=53
	replace apet2_coarse=11 if  apet2>=58 & apet2<=63
	replace apet2_coarse=12 if  apet2>=55 & apet2<=56
	replace apet2_coarse=13 if  apet2>=64 & apet2<=66
	replace apet2_coarse=14 if  apet2>=68 & apet2<=82
	replace apet2_coarse=15 if  apet2==85
	replace apet2_coarse=16 if  apet2>=86 & apet2<=88
	replace apet2_coarse=17 if (apet2>=90 & apet2<=93) | apet2==95 | apet2==96 
	replace apet2_coarse=18 if  apet2==94
	replace apet2_coarse=19 if  apet2==84
	
	* Keep crosswalk structure as dta file
		preserve
			gen a=1
			collapse a, by(apet2 apet2_coarse)
			drop a
			save industry_crosswalk,replace
		restore


		gen colbarg= irc					//  code of collective barganing agreement applied to worker
		tostring colbarg, replace			
		gen type_aggrement	=	substr(colbarg,1,1)			// first digit of coll. bar. agreement code refers to type of agreemenrt:
		*															 1-Agreemente between 2 or more firms and unions
		*															 2-Agreemente between employer association and unions 
		*															 3- Ordinance
		*															 4- firm-level Agree
		*															 9- No CollBargAgree


		gen CB1_1=				type_aggrement=="1"	|	type_aggrement=="2"	| type_aggrement=="4" // Any CBA
		gen CB2_1=				type_aggrement=="2"												 // Sector CBA
		gen CB3_1=				type_aggrement=="1"	|	type_aggrement=="4"						 // Firm CBA

		
		* Compute average coverage of each type of CBA per year and industry (industry harmonized with german data)
		collapse (mean) CB1_1_apet2_coarse=CB1_1 CB2_1_apet2_coarse=CB2_1 CB3_1_apet2_coarse=CB3_1, by(apet2_coarse year)
		* Compute average coverage of each type of CBA across all years for each industry (industry harmonized with german data)				
		collapse (mean) CB1_1_apet2_coarse=CB1_1 CB2_1_apet2_coarse=CB2_1 CB3_1_apet2_coarse=CB3_1, by(apet2_coarse)				
		* Generate High coverage dummy
		sum CB1_1, detail
		gen CB1_2_apet2_coarse= CB1_1>r(p50)			// High coverage by any CBA
		sum CB2_1, detail
		gen CB2_2_apet2_coarse= CB2_1>r(p50)			// High coverage by sector CBA			
		sum CB3_1, detail				
		gen CB3_2_apet2_coarse= CB3_1>r(p50)			// High coverage by firm CBA
		save coll_barg_apet2_coarse.dta, replace

			
			
		use industry_crosswalk, clear
		merge m:1 apet2_coarse using coll_barg_apet2_coarse
		drop _m
		save ../dta/idustry_share_cba, replace

log close
	

log using ../log/data_prep_prev_and_following_years.log, replace

**********************************************************************************************************
************************************** III - CONSTRUCTION OF VARIABLE FOR PREVIOUS YEARS ****************
**********************************************************************************************************

* 1) PRESENCE PREVIOUS YEAR
* This short routine creates three datasets containing variables indicating absence/presence in the year before
* The three datasets are:
* - P1sircom: with variables indicating presence in the same firmXmunicipality
* - P1siren: with variables indicating presence in the same firm
* - P1: with variables indicating presence in the country (with absence implying not in dependent employment)
* The variable is:
* - P1m: presence in the same month of the year before (October for Portugal)
* when presence refers to same firmXmunicipality or same firm, respectively,
* P1m is followed by the postfix sircom or siren, respectively

use ../dta/PanelbaseFUA.dta, clear

* create variables (presence requires a valid spell)


* create variables (presence requires a valid spell and a remuneration)



*Question: for me I only have P1m
ge P1m = 1


collapse (max) P1m, by(nninouv sircom sir year)
* create a numeric variable for the year (will be used for merging)
gen an=year
* lagging one year
replace an=an+1
* drop out of sample year  !!!!!!!!!!!!!!!! put 2020 when in GEP
drop if an==2020
* renaming variables for each level of aggregation
rename P1m P1msircom
sort nninouv sircom sir an
save P1sircom, replace
drop sircom
collapse (max) P1m , by(nninouv sir year an)
rename P1m P1msiren
sort nninouv sir an
save P1siren, replace
collapse (max) P1m, by(nninouv an)
rename P1m P1m
sort nninouv an
save P1, replace


log close


cap log c
log using ../log/data_prep_assemblingfinaldatasets.log, replace

**********************************************************************************************
***********************IV- ASSEMBLING FINAL DATASETS FOR THE REGRESSIONS *********
**********************************************************************************************

* 1) DATA WAGE REGRESSIONS

use ../dta/PanelbaseFUA.dta, clear

* keep observations with at least 30 days of spell in the year
keep if dtadm<ym(year ,9)	 // total employees with at least one month of tenure
				
				*keep industries - CAE2 is the 2 digit NACE of the firm while CAE2_est is the 2 digit NACE of the establishment
					
					destring apet2, replace					
					keep if (apet2>=5 & apet2<=82 )| apet2==90 | (apet2>=92 & apet2<=96)
	

** generate full-time indicator
ge ftpt=(reg_dur==1)

* hourly wage (wage: trimmed top/bottom 1%, wagew: winsorised top/bottom 1%, wagen: no treatment)
* trimming and winsorising are done year by year on the national distribution

**************************** Hourly wage *******************


* hourly wage based on basic wage + regular payments + extra hours
ge wage_g_nolog=(rganho/(hnormais+hextra))
ge wage_g=log(rganho/(hnormais+hextra))


**************************** hourly wage - FULLTIMERS ************************

* hourly wage based on basic wage + regular payments + extra hours
ge wage_g_ft_nolog=(rganho/(hnormais+hextra))  if ftpt==1
ge wage_g_ft=log(rganho/(hnormais+hextra))  if ftpt==1

**************************** monthly wage - FULLTIMERS ************************

* hourly wage based on basic wage + regular payments + extra hours
ge wage_g_ft_m_nolog=rganho if ftpt==1
ge wage_g_ft_m=log(rganho)  if ftpt==1

gen an=year

local wagetype _g _g_nolog _g_ft _g_ft_nolog _g_ft_m _g_ft_m_nolog		

foreach w of loc wagetype {
	foreach year of numlist 2010/2019 {
		sum wage`w' if an==`year',d  //drop extreme values 
		replace wage`w'=. if inrange(wage`w',`r(p1)',`r(p99)')!=1 & an==`year'&wage`w'!=.
	}
}				

		
** creation of fixed effects

		egen firm=group(sir)
		egen mun=group(comt)
		egen occ=group(pcs)
		egen geo=group(fuaX) 
		egen nuts=group(dep) 
		egen fua1_n=group(fua1) 
		egen ind=group(apet2)
		egen id=group(nninouv) 
		egen nic=group(nic4)
		egen ag=group(age)
		
			* missing age as an additional age category
			* replace ag=0 if age==. ---- Question: for PRT age in not a continous variable for now (once I have access to the raw data I will have month and year of birth)
					* cluster variables
					egen cluster=group(geo occ an)
					egen cluster2=group(nuts occ an)
					egen cluster3=group(fua1_n occ an)


compress
* drop 2010
drop if year<=2010

save prewage, replace

keep firm mun occ geo nuts fua1_n ind id nic ag* cluster* wage* ftpt sx year sir  nninouv sirc fua fua1 fuaX fua1_n dep nuts comt pcs an habil1 tipo_contr1
save prewage_compact, replace


* 2) DATA CONTRACT REGRESSIONS
use ../dta/PanelbaseFUA.dta, clear
keep if dtadm<ym(year ,9)	 // total employees with at least one month of tenure

* drop 2010 for PRT for now (until I include years prior to 2010)
drop if year<=2010
	*keep industries - CAE2 is the 2 digit NACE of the firm while CAEST2 is the 2 digit NACE of the establishment
					
					destring apet2, replace					
					keep if (apet2>=5 & apet2<=82 )| apet2==90 | (apet2>=92 & apet2<=96)
	
** generate full-time indicator
ge ftpt=(reg_dur==1)

ge perm = (tipo_contr1==1)

* generate fixed effects
					gen an=year
					destring sx, replace

		egen firm=group(sir)
		egen mun=group(comt)
		egen occ=group(pcs)
		egen geo=group(fuaX) 
		egen nuts=group(dep) 
		egen fua1_n=group(fua1) 
		egen ind=group(apet2)
		egen id=group(nninouv) 
		egen nic=group(nic4)
		egen ag=group(age)
			* missing age and education as additional age and education categories			
			replace ag=0 if ag==.
			replace habil1=9 if habil1==.
					* cluster variables
					egen cluster=group(geo occ an)
					egen cluster2=group(nuts occ an)
					egen cluster3=group(fua1_n occ an)
		

compress
save precontract, replace
keep firm mun occ geo nuts fua1_n ind id nic ag* cluster* wage* ftpt perm sx year sir  nninouv sirc fua fua1 fuaX fua1_n dep nuts comt pcs an habil1 dtadm
save precontract_compact, replace

log close
clear
