******************************************************************************************
*
*			
*		do-file:
*					this programme produces the descriptive stratistics for Portugal that are presented in both the Manuscript and in Appendix 1
*
*
*   Statistics in the Manuscript 	Table 1      – statistics from line 53 of this do-file
*									Footnote 18  – statistics from line 260 of this do-file
*									Footnote 33  – statistics from line 757 of this do-file
*
*
*   Statistics in Appendix 1 		Table  1.1   – statistics from  line 348 to 430 of this do-file
*									Table  1.2   – statistics from  line 157 of this do-file
*					 				Figure 1.1   – statistics from  line 125 of this do-file
*									Footnote 53  – statistics from  line 60 of this do-file
*									Footnote 51 and 52  – statistics from  line 133 of this do-file

******************************************************************************************

set more off

cap log c
log using ../log/Descriptive_stats_ManuscriptTable1.log, replace

************************************************************************************
*********************** Descriptive Statistics Table 1 *****************************
************************************************************************************

* the following loop computes the descriptive statistics presented in Table 1

local aggregateL  sircomt siren 
local zoneL fuaX      

global HHI Share_E
global perm perm
global Hires Z_E

foreach x of numlist 2/2 {										// x regards type of hiring concept here (2= month/year).
		foreach zone of loc zoneL {		
			foreach aggregate of loc aggregateL {
					* input data
					disp "XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX"
					disp "HHI `zone' `aggregate'  -  Weighted by New Hires " 
					disp "XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX"
					
					use  ../dta/HHI/HHI`x'_HP`aggregate'`zone'_pcs41, clear				
					
					disp "------------------------------------------------------------------------------------------------------------------------------------------------------------"
					disp "------------- Table 1: Labor market concentration ----------------------------------------------------------------------------------------------------------"
					disp "------------------------------------------------------------------------------------------------------------------------------------------------------------"
					if "`y'"=="sircomt" {
					sum $HHI [w=$Hires] if $HHI !=0 & $HHI !=. , de
					}
					
					disp "------------------------------------------------------------------------------------------------------------------------------------------------------------"
					disp "------------- Appendix Footnote 53: HHI distribution -------------------------------------------------------------------------------------------------------"
					disp "------------------------------------------------------------------------------------------------------------------------------------------------------------"
					if "`y'"=="siren" {
					sum $HHI [w=$Hires] if $HHI !=0 & $HHI !=. , de
					}
				
				}
		}
}

log close


cap log c
log using ../log/Appendix_descriptive_stats_HHI.log, replace

***************************************************************************************
*********************** Descriptive Statistics Figure 1.1 *****************************
***********************     by type of firm identifier    *****************************
***************************************************************************************

* 

** COMPARING TYPES OF FIRM IDENTIDIERS
				
local zoneL fuaX					

foreach m of numlist 1/1 {				// all have 1 month tenue: m=1
	foreach zone of loc zoneL {
		foreach x of numlist 2/2 {		// month/year definition is the only applicable to PORTUGAL: x=2 

			disp in ye "`m'"
			disp in ye "`zone'"
			disp in ye "`x'"
				
			* inputing HHI type of identifier
			use ../dta/HHI/HHI`x'_HPsiren`zone'_pcs4`m', clear
				
			foreach y of varlist nb_Dm Share_E Z_E headcount {
				ren `y' `y'T
			}
				
			sort `zone' pcs year
			qui merge 1:1 `zone' pcs year using ../dta/HHI/HHI`x'_HPsircomt`zone'_pcs4`m'
			drop _m
			foreach y of varlist nb_Dm Share_E Z_E headcount {
				ren `y' `y'M
			}
			* creating logarithms
			foreach y of varlist Share* {
				ge log`y'=log(`y')
				replace `y'=. if `y'==0
			}
			
			global logHHIf logShare_ET
			global logHHIfm logShare_EM
			global Hires Z_ET
			global Countryname "Portugal"
			
			* making charts
				
			disp "------------------------------------------------------------------------------------------------------------------------------------------------------------"
			disp "------------- Figure 1.1: Correlations between logHHI constructed using firm-by-municipality and firm identifiers ------------------------------------------"
			disp "------------------------------------------------------------------------------------------------------------------------------------------------------------"

			label var $logHHIf "log HHI (based on firm identifiers)"
			label var $logHHIfm "log HHI(based on firmXmunicipality identifiers)"
			
			twoway scatter $logHHIfm $logHHIf , msize(tiny) title($Countryname)
			graph save "HHIfmHHIf_$Countryname", replace
			graph export "../HHIfmHHIf_$Countryname.png", replace
			
			disp "------------------------------------------------------------------------------------------------------------------------------------------------------------"
			disp "-------------------------------------- Footnote 51 and 52: Regression --------------------------------------------------------------------------------------"
			disp "------------------------------------------------------------------------------------------------------------------------------------------------------------"
			disp "regressions HHI`x' `zone'_pcs4A`m'"
			regr $logHHIfm $logHHIf [pw=$Hires], robust
		}
	}
}

log close
clear


cap log c
log using ../log/A_descriptive_stats_Manuscriptfootnote18_AppendixTable1.log, replace


************************************************************************************
*********************** Descriptive Statistics Appendix Table 1.1 ******************
************************************************************************************

local aggregateL    sircomt 
local zoneL fuaX     



*---------------------- Descriptive Statistics: Wage regressions Sample -----------------------------------------------

					
foreach var in wage_g_ft wage_g wage_g_ft_m     {
		foreach y of loc aggregateL {	
			foreach zone of loc zoneL {		
			* type of hiring concept here (1 for year, 2 for month/year, 3 for week/year). For all three set numlist 1/3. Given the nature of the wage data, only the year concept makes sense
				foreach x of numlist 2/2 {
				
					* input data
					use prewage_compact, clear

					disp "XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX"
					disp "`var' HHI`x' `zone' `y'" 
					disp "XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX"

					disp "*********************************************************************"
					disp "******************* DATA LOAD & PREPARATION: For descriptives *******"
					disp "*********************************************************************"
										
					* when monthly wage for fulltimers (wage_g_ft_m) or daily wages of fulltimers (wage_g_ft) is the dep variable, keep only full time employees
					if "`var'"=="wage_g_ft" |"`var'"=="wage_g_ft_m" {
						keep if ftpt==1
					}
					
					* merge with presence previous year
						sort nninouv sircom sir an
						merge m:1 nninouv sircom sir an using P1sircom, gen(_m3)
						drop if _m3==2
						drop _m3
	
					*drop P1m   // I think it is the only one variable that I can define using Quadros de Pessoal
					sort nninouv an
					merge m:1 nninouv an using P1, gen(_m3)
					drop if _m3==2
					drop _m3

					* generate indicators for being new hire and employed the year before (if new hire)	Question

					* using the month/year concept, then one would define new hires as
					ge Hirem=(P1msir!=1) 
					ge Emp1=(Hirem*P1m==1)
					
					drop P1*
	
					* merge with HHI data
					sort `zone' pcs year			
					merge m:1 `zone' pcs year using ../dta/HHI/HHI`x'_HP`y'`zone'_pcs41 , gen(_m3)	
					keep if _m3==3
					drop _m3	

					* define logarithm of HHI
					ge logShare_E=log(Share_E)
					
					compress
		
					* For descriptive statistics
					gen educ_bel_upsec	=	habil1==1 | habil1==2
					gen educ_upsec		=	habil1==0 | habil1==3
					gen educ_ab_upsec	=	habil1>=4 & habil1<=8
					gen educ_missing	=	habil1==9 | habil1==.
					ge perm = (tipo_contr1==1)
					replace sx= sx-1 // sx=1 for men and sx =2 for women
					
					****************** IMPORTANT STEP TO PRODUCE APPENDIX TABLE 1.1
					****************** SAVE PREPARED DATASET
					keep if `var'!=. & ftpt!=. & logShare_E!=. & Hire!=. & Emp1!=. & id!=. & occ!=. & geo!=. & firm!=. & mun!=. & an!=. & firm!=. & nic!=. & age!=. // to ensure sample is the same used in regressions					
					
					save descriptive_`var', replace
					
					disp "*****************************************************************"
					disp "******************* DESCRIPTIVE STATISTICS **********************"
					disp "*****************************************************************"
										
					disp "------------------------------------------------------------------------------------------------------------------------------------------------------------"
					disp "------------- Footnote 18: Mean number of occupations per firm-by-municipality couple. ---------------------------------------------------------------------"
					disp "------------------------------------------------------------------------------------------------------------------------------------------------------------"
					if "`var'"=="wage_g_ft_m" {				
					
					global occ occ
					global sircom sircomt
					global year an

					global HHI Share_E
					global perm perm
					global Hires Z_E
					
					tempfile curent_dataset   // need to do this as I already preserved the data
					save `curent_dataset', replace
					
					ge one=1
					collapse (count) one,by($occ $sircom $year)
					duplicates tag $sircom $year, ge(numb_occ)
					replace numb_occ=numb_occ+1
					drop one
					sort $occ $sircom $year
					tempfile numb_occ   // need to do this as I already preserved the data
					save `numb_occ', replace					
					 
					use `curent_dataset', clear
					merge m:1 $occ $sircom $year using `numb_occ'
					drop if _m==2
					drop _m
					sum numb_occ
					
					disp " mean number of occupations" r(mean)
					disp " std number of occupations:" r(sd)
					}
					
	
}
}
}
}

*---------------------- Descriptive Statistics: Contract regressions Sample -----------------------------------------------

local aggregateL    sircomt
local zoneL fuaX     

foreach x of numlist 2/2 {
		foreach zone of loc zoneL {		
			foreach y of loc aggregateL {
			* for the HHI computed with the year concept (HHI1) only the yearly variable makes sense, otherwise perm_m is based on the month/year concept

					local variable perm_m
					
					foreach var of loc variable { 
				
				* input data
					use precontract_compact, clear

					disp "XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX"
					disp "HHI`x' `zone' `y'" 
					disp "XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX"

					*merge with presence previous year 

						sort nninouv sircom sir an
						merge m:1 nninouv sircom sir an using P1sircom
						drop if _m==2
						drop _m
								
					sort nninouv an
					merge m:1 nninouv an using P1
					drop if _m==2
					drop _m

					* generate indicators for being new hire (year and month/year definitions)	
					ge Hirem=(P1msir!=1)
					keep if Hirem==1
					
					* generate indicators for at work if new hire (year and month/year definitions)	
					ge Emp1=(Hirem*P1m==1)

					drop P1msir
	
	
					* merge with HHI
					sort `zone' pcs year			
					qui merge m:1 `zone' pcs year using ../dta/HHI/HHI`x'_HP`y'`zone'_pcs41	
					keep if _m==3
					drop _m	

					compress			
		
					rename perm perm_m	

					* For descriptive statistics
					gen educ_bel_upsec	=	habil1==1 | habil1==2
					gen educ_upsec		=	habil1==0 | habil1==3
					gen educ_ab_upsec	=	habil1>=4 & habil1<=8
					gen educ_missing	=	habil1==9 | habil1==.
					gen woman=sx==2&sx!=.
					replace sx= sx-1 // sx=1 for men and sx =2 for women

					keep if `var'!=. & Hirem==1  & ftpt!=. & sx!=. & logShare_E!=. & Emp1!=. & occ!=. & geo!=. & firm!=. & mun!=. & an!=. & firm!=. & nic!=. & age!=. & habil1!=.  // to ensure sample is the same used in regressions					
					
					save descriptive_perm, replace
						
			}
		}
	}
}
					



					disp "------------------------------------------------------------------------------------------------------------------------------------------------------------"
					disp "------------- Appendix table 1.1: --------------------------------------------------------------------------------------------------------------------------"
					disp "------------------------------------------------------------------------------------------------------------------------------------------------------------"
					
					
					disp "-------- Row: HHI---------------------------------------------------------------"
									use  descriptive_wage_g_ft_m, clear	
									sum Share_E								 										//  Column: full sample
									
									use  descriptive_perm, clear										
									sum Share_E																		//  Column: New hires
									sum Share_E	if	dtadm>=ym(year ,6)&dtadm<=ym(year ,8)							//  Column: New hires hired between June and August
								
					disp "-------- Row: Monthly wage (full-timers)---------------------------------------"
									use  descriptive_wage_g_ft_m, clear	
									sum wage_g_ft_m_nolog															// Column: full sample
									sum wage_g_ft_m_nolog if Hire==1 												// Column: New hires
									sum wage_g_ft_m_nolog if Hire==1 &dtadm>=ym(year ,6)&dtadm<=ym(year ,8)			// Column: New hires hired between June and August	
											
								
					disp "-------- Row: Hourly wage (full-timers)----------------------------------------"
									use  descriptive_wage_g_ft, clear	
									sum wage_g_ft_nolog																// Column: full sample
									sum wage_g_ft_nolog if Hire==1 													// Column: New hires
									sum wage_g_ft_nolog if Hire==1 &dtadm>=ym(year ,6)&dtadm<=ym(year ,8)			// Column: New hires hired between June and August	
								
								
					disp "-------- Row: Hourly wage  ---------------------------------------------------"
									use  descriptive_wage_g, clear	
									sum wage_g_nolog																// Column: full sample
									sum wage_g_nolog if Hire==1 													// Column: New hires
									sum wage_g_nolog if Hire==1 &dtadm>=ym(year ,6)&dtadm<=ym(year ,8)				// Column: New hires hired between June and August	
																										

					disp "-------- Row: Women   --------------------------------------------------------"
									use  descriptive_wage_g_ft_m, clear	
									sum sx																			// Column: full sample
									
									use  descriptive_perm, clear										
									sum sx																			//  Column: New hires
									sum sx	if	dtadm>=ym(year ,6)&dtadm<=ym(year ,8)								//  Column: New hires hired between June and August
																										
									
					disp "-------- Row: Age   ---------------------------------------------------------"
									use  descriptive_wage_g_ft_m, clear	
									sum age																			// Column: full sample
									
									use  descriptive_perm, clear										
									sum age																			//  Column: New hires
									sum age	if	dtadm>=ym(year ,6)&dtadm<=ym(year ,8)								//  Column: New hires hired between June and August																	
																		
					disp "-------- Row: Full-time work   --------------------------------------------"
									use  descriptive_wage_g_ft_m, clear	
									sum ftpt																		// Column: full sample
									
									use  descriptive_perm, clear										
									sum ftpt																		//  Column: New hires
									sum ftpt if	dtadm>=ym(year ,6)&dtadm<=ym(year ,8)								//  Column: New hires hired between June and August																	
									
					disp "-------- Row: Education   ------------------------------------------------"
									use  descriptive_wage_g_ft_m, clear	
									sum educ*																		// Column: full sample
									
									use  descriptive_perm, clear										
									sum educ*																		//  Column: New hires
									sum educ* if	dtadm>=ym(year ,6)&dtadm<=ym(year ,8)							//  Column: New hires hired between June and August	
									

					disp "-------- Row: New Hires   -----------------------------------------------"
									use  descriptive_wage_g_ft_m, clear	
									sum Hire																		// Column: full sample
									* Not Applicable to New Hires													//  Column: New hires
									* Not Applicable to New Hires(June and Aug) 									//	Column: New hires hired between June and August	
									

					disp "-------- Row: Employed year before if new hire -------------------------"
									* Not applicable to full sample													// Column: full sample
									use  descriptive_perm, clear										
									sum Emp1																		//  Column: New hires
									sum Emp1 if	dtadm>=ym(year ,6)&dtadm<=ym(year ,8)								//  Column: New hires hired between June and August	
									

					disp "-------- Row: New hires on perm. contract ------------------------------"
								if "`var'"=="wage_g_ft_m" 	
									* Not applicable to full sample													// Column: full sample
									use  descriptive_perm, clear										
									sum perm_m																		//  Column: New hires
									sum perm_m if	dtadm>=ym(year ,6)&dtadm<=ym(year ,8)							//  Column: New hires hired between June and August	
																		

log close

cap log c



cap log c
log using ../log/A_descriptive_stats_footnote33.log, replace


************************************************************************************
*********************** Descriptive Statistics Foornote 33 *************************
************************************************************************************

*******************  Transition Probablities 				************

*** until 6th step we can work with regressions dataset

global panel = "PanelbaseFUA.dta"
global year=year
global maxyear = 2019
global minyear = 2010
global newminyear = 2011



***** Preliminary step: construct a variable identifying new hires
use ../dta/PanelbaseFUA.dta, clear

*absent year before

*Question: for me I only have P1m
ge P1m = 1


collapse (max) P1m, by(nninouv sircomt year)
* create a numeric variable for the year (will be used for merging)
gen an=year
* lagging one year
replace an=an+1
drop if an==$maxyear +1

* renaming variables for each level of aggregation
rename P1m P1msircom
sort nninouv sircomt an
save P1sircom_transitions, replace


collapse (max) P1m, by(nninouv an)
rename P1m P1m
sort nninouv an
save P1_transitions, replace


***** First step: create a database with variabes for observation at t and t-1 (to avoid tsetting)
use ../dta/PanelbaseFUA.dta, clear

gen an=year
replace an=an+1
drop if an==$maxyear +1

*** first condition for identification of main job: main job one year ago should be at least 30 days duration
keep if dtadm<ym(year,9)

rename pcs pcs_1
gen nbheur_1=hnormais+hextra
rename rganho netnet_1

keep an sircomt nic nninouv pcs_1 nbheur_1 netnet_1

keep if regexm(pcs,"^[0-9][0-9][0-9][0-9]")
drop if mi(pcs)

sort nninouv sircomt nic an
save indiv_origin_transitions, replace

* merging with variable containing current job matches

use ../dta/PanelbaseFUA.dta, clear

gen an=year
drop if an== $minyear

keep if dtadm<ym(year,9)

* keep industries
					
					destring apet2, replace					
					keep if (apet2>=5 & apet2<=82 )| apet2==90 | (apet2>=92 & apet2<=96)
	
* find new hires and keep only new hires
sort nninouv sircomt an 
merge m:1 nninouv sircomt an  using P1sircom_transitions
drop if _m==2
drop _m

					sort nninouv an
					merge m:1 nninouv an using P1_transitions
					drop if _m==2
					drop _m
					ge Hirem=(P1msir!=1) 
					ge Emp1=(Hirem*P1m==1)


					keep if Hirem==1



* renaming some variables as in French code
gen nbheur=hnormais+hextra
rename rganho netnet

					
* merging with records of the previous year


sort nninouv nic sircomt an 
merge 1:1 nninouv nic sircomt an using indiv_origin_transitions				
ren _m mergeorigin


preserve
keep if Hire==1
keep nninouv
bysort nninouv: keep if _n==1

save newhires_id, replace

restore
merge m:1 nninouv using newhires_id
drop if _m!=3
drop _m

save temp_trans_2, replace
*** second step: identifying the main job previous year among those with at least 30 days duration
* looping over years
foreach y of numlist 2011 / 2019 {
	use temp_trans_2, clear

	ge p1=1 


	* making dataset smaller
	
		*drop if:
		
		*Individuals who in 2010 would not be NewHires in 2011 
		keep if an==`y'
		egen H=max(Hire), by(nninouv)
		drop if H!=1
		drop H 

		*If there is only 1 observation for a given identifier then we cannot observe occupational mobility 	
		bysort nninouv: gen N=_N
		keep if N>1	
		drop N

		* New Hires with more than one observation in 2011 but which dont share
		* the individual identifier with observation from 2010
		* meaning we cannot observe occupational mobility 
		
		gen NotH=Hire==.
		egen mNotH=max(NotH), by(nninouv)
		drop if mNotH==0
		drop NotH mNotH
		
	quietly des
	display "`r(N)'"
	* second condition: pick that with the same occupation, if there is any
	ge occorigin=""
	levelsof pcs_1, local(pcs)

	foreach p of local pcs {
		disp `y' "  `p'"
		ge p1_`p'=(pcs_1=="`p'")
		egen maxp1_`p'=max(p1_`p'), by(nninouv )
		replace occorigin="`p'" if pcs =="`p'"&maxp1_`p'==1
		drop p1_`p' maxp1_`p'
	}
	
	* indicators for max duration, max hours (if same duration) and max salary (if same duration and hours)
	egen maxh=max(nbheur_1)	, by(nninouv )
	egen maxw=max(netnet_1)	if abs(maxh-nbheur_1)<1, by(nninouv )
	
	** NOTE: in order to "transfer" the occupation of origin from one job match the year before to a current one, I use the operator "mode"
	* which works also for alphanumeric variables
	
	
	* third (fourth for France) condition: among ties, pick the one with the longest hours, if there are no new ties 
	* (occmode, tag, tag2 & mode play the same role as before)
	ge occmode=pcs_1 if abs(maxh-nbheur_1)<1
	duplicates tag nninouv if occmode!="", ge(tag)
	duplicates tag nninouv occmode if occmode!="", ge(tag2)
	egen mode=mode(occmode) if tag==tag2, by(nninouv )
	gen a=mode!=""
	tab a
	tab a if occorigin==""
	drop a
	replace occorigin=mode if occorigin==""
	drop mode occmode tag tag2
	
	* fourth (fifth for FR) condition: among the new ties, pick the one with the highest salary, if there are no new ties
	* (occmode, tag, tag2 & mode play the same role as before)
	ge occmode=pcs_1 if abs(maxh-nbheur_1)<1&abs(maxw-netnet_1)<1
	duplicates tag nninouv if occmode!="", ge(tag)
	duplicates tag nninouv occmode if occmode!="", ge(tag2)
	egen mode=mode(occmode) if tag==tag2, by(nninouv )
	gen a=mode!=""
	tab a
	tab a if occorigin==""
	drop a
	replace occorigin=mode if occorigin==""
	drop mode occmode tag tag2
	
	* 	fifth (sixth for FR) condition: among the new ties, pick the most frequent, if there are no new ties
	ge occmode=pcs_1 if abs(maxh-nbheur_1)<1&abs(maxw-netnet_1)<1&occorigin==""
	egen mode=mode(occmode), by(nninouv )
	gen a=mode!=""
	tab a
	tab a if occorigin==""
	drop a
	replace occorigin=mode if occorigin==""
	drop mode occmode

	* 	sixth (seventh for FR) condition: among the new ties, pick one at random
	set seed 1
	ge u=runiform()
	ge d=abs((_n/_N)-u)
	egen mind=min(d) if abs(maxh-nbheur_1)<1&abs(maxw-netnet_1)<1&occorigin=="", by(nninouv )
	ge occmode=pcs_1 if abs(maxh-nbheur_1)<1&abs(maxw-netnet_1)<1&abs(mind-d)<0.00000001&occorigin==""
	egen mode=mode(occmode), by(nninouv )
	gen a=mode!=""
	tab a
	tab a if occorigin==""
	drop a
	replace occorigin=mode if occorigin==""
	drop mode occmode
	
	quietly des
	display "`r(N)'"	
** cleaning up (normally not needed)
	keep if pcs!=""
	keep if occorigin!=""
	
	compress
	
	save temp_t_transit`y', replace
	
}


*** third step: construct a squared matrix of occupation
use ../dta/HHI/HHI2_HPsircomtfuaX_pcs41, clear
collapse (sum) Z_E, by(pcs )
ge one=1
ren Z_E Z_E0
sort one
save pcs_list_trans, replace
ren pcs occorigin
ren Z_E Z_E1
sort one
joinby one using pcs_list_trans
keep pcs occorigin Z_E1 Z_E0
sort pcs occorigin
save pcs_squared_trans, replace


*** fourth step: transition probabilities and factors (that is relative probabilities divided by relative # of new hires)

* create a frequency dataset by current and previous year occupations (main job only as defined above for previous year) 
clear
set obs 1
ge v1=.
save tprob_trans, replace

foreach y of numlist 2011 / 2019 {
	use temp_t_transit`y', clear
	collapse (sum) p1, by(occorigin pcs )
	replace p1=0 if p1==.
	ge year="`y'"
	append using tprob_trans
	save tprob_trans, replace

	
}

use tprob_trans, clear

drop if p1==.

* summing frequency over years
collapse (sum) p1, by(pcs occorigin)
label var p1 "frequency of occupation couple"
sort pcs occorigin
merge 1:1 pcs occorigin using pcs_squared_trans
drop if _m==1
replace p1=0 if p1==.

*cleaning
drop _m
sort pcs
compress

* ge dummy for within 2-digit transitions2&4
ge same2=(substr(pcs,1,2)==substr(occorigin,1,2))

*ge dummy for within 4 digit transition
ge same4=(pcs==occorigin)

*ge occupation codes for 2 digit occupations of origin
ge occ2=substr(occorigin,1,2)

* ge frequency of within 2 and 4 digit transitions
ge trans2=p1*same2
ge trans4=p1*same4

*collapse at occ2 level and compute share of within 2 digit transitions accounted for by 4-digit transitions2&4
preserve
collapse(sum) trans2 trans4 p1, by(occ2)

					disp "------------------------------------------------------------------------------------------------------------------------------------------------------------"
					disp "------------- Footnote 33: % transitions within the same 2-digit occupational category have the same 4-digit origin and destination ------------------------"
					disp "------------------------------------------------------------------------------------------------------------------------------------------------------------"
						ge ratio=trans4/trans2
						sum ratio[aw=p1]
						 
restore
log close


************************************************************************************
*********************** Descriptive Statistics Appendix 1 Table 1.2 ****************
************************************************************************************

cap log c
log using ../log/Appendix1Table2.log, replace

use ../dta/PanelbaseFUA.dta, clear

keep irc year sir nic4 apet2
compress


gen colbarg= irc					//  code of collective barganing agreement applied to worker
tostring colbarg, replace			

gen type_aggrement	=	substr(colbarg,1,1)			// first digit of coll. bar. agreement code refers to type of agreemenrt:
*															 1-Agreemente between 2 or more firms and unions
*															 2-Agreemente between employer association and unions 
*															 3- Ordinance
*															 4- firm-level Agree
*															 9- No CollBargAgree

gen CBA_types=""
replace CBA_types=="Firm-level collective agreement" if type_aggrement=="1" | type_aggrement=="4"
replace CBA_types=="Sector-level collective agreement" if type_aggrement=="2"
replace CBA_types=="No agreement" if type_aggrement=="9" | type_aggrement=="3"

					disp "------------------------------------------------------------------------------------------------------------------------------------------------------------"
					disp "------------- Appendix 1 Table 1.2: Proportion of workers covered by collective bargaining, by type of agreement -------------------------------------------"
					disp "------------------------------------------------------------------------------------------------------------------------------------------------------------"
					tab CBA_types

			