*******************************************************************************

*** LABOR MARKET CONCENTRATION, WAGES AND JOB SECURITY IN EUROPE

*** (C) MICHAEL OBERFICHTNER & MARTIN POPP

*******************************************************************************


*** 0. MASTER FILE ***


*** 0.1 PREAMBLE ***


*clear memory 

clear all


*activate rmsg command

set rmsg on


*deactivate more function

set more off, permanently


*specify Stata version

version 16


*faster calculations (but more memory needed) for mata 

mata: mata set matafavor speed, perm


*set seed number
         
set seed 1265674183
		 
*increase maximum size for matrices

set matsize 10000


*increase maximum size for matrices

set maxvar 10000


*save current date in macro

global cdate : di %tdCCYY-NN-DD date(c(current_date), "DMY")
display %tdCCYY-NN-DD "$cdate"


*save paths for working directory as global


global main = "\\iab.baintern.de\DFS\017\Ablagen\D01700-Projekte\4063-HHI\6_Empirics"
global data = "$main\data" 
global doc = "$main\doc"
global fig = "$main\fig"
global file ="$main\file"
global log = "$main\log"
global orig = "$main\orig"
global prog ="$main\prog"



*specify working directory

cd "$main"


*add path for ado directories

sysdir set PERSONAL "$prog\ado\personal" // self-written ado files 
sysdir set PLUS "$prog\ado\stbplus" // installed ado files (via "ssc install ...")
sysdir set OLDPLACE "$prog\ado\oldplace" // no longer needed

*tell mata where ado directories are

mata: mata mlib index

sysdir


*install ado files (in PLUS directory)

*ssc install mergepoly // v. 2.0.5
*ssc install shp2dta // v. 1.0.9
*ssc install spmap // v. 1.3.2
*ssc install reghdfe // v. 5.7.3
*ssc install ivreghdfe // v. 1.0.0
*ssc install plausexog // v. 3.1.2


*ado
*adoupdate




*** 0.1 LABELS ***

log using $log\0_1_Labels.log, replace

do $prog\0_1_Labels.do 

log close

exit


*** 1. PREPARATION OF DATA ***


log using "$log\1_Preparation_of_Data_$cdate.log", replace 

do "$prog\1_1_Preparation_of_HHI.do"
do "$prog\1_2_Arnold_HHI.do"
do "$prog\1_3_Preparation_of_Variables.do"


log close 





*** 2. DESCRIPTIVE ANALYSIS ***


log using "$log\2_Descriptive_Analysis_$cdate.log", replace 

do "$prog\2_Descriptive_Analysis.do"

log close 





*** 3. REGRESSION ANALYSIS ***


log using "$log\3_Regression_Analysis_$cdate.log", replace 

do "$prog\3_Regression_Analysis.do"

log close 













