


*** 1.5 ARNOLD-TYPE LABOR MARKET CONCENTRATION: EMPLOYMENT ***



*** 1.5.1 TRANSITION PROBABILITIES ***


**** first preliminary step: construct a variable identifying new hires (normally you should have done it already - but you may
**** find it convenient to follow these steps if you want to run the code by only inputing the macro names above
**** in fact, this step is unnecessary now and could be skipped, except that you must eliminate it from the merges below



use "$data\LMC_1019_V3.dta", clear 


sort ieb_fall_id


drop *_end


merge 1:1 ieb_fall_id using "$data\inflow_year_01.dta", keepusing(inflow_year_01)
replace inflow_year_01 = . if _merge==1  // spells that do not include reference period, here==0 as no spells are dropped in year concept
drop _merge


merge 1:1 ieb_fall_id using "$data\employment_year_01.dta", keepusing(employment_year_01)
replace employment_year_01 = . if _merge==1  // spells that do not include reference period, here==0 as no spells are dropped in year concept
drop _merge


duplicates report prs_id betnr year

merge 1:1 ieb_fall_id using "$data\LMC_1019_V3_Arnold.dta"
keep if _merge==3  // keep only most important spell per person-establishment-year triple (i.e., one spell per yearly job match) to conform with French data
drop _merge

*duplicates report prs_id betnr year

bysort prs_id betnr year: gen n = _n
tab n, m

drop n

tab year, m 
keep if inrange(year,2011,2018) // in order to analyse transitions between 2011 and 2017, i.e. t=2012,2013,2014,2015,2016,2017 (2018 only needed to check whether person is still in firm at t+1)


*keep if ( type==1 | type==6 ) // regular/other full-time employment
*keep if ( type==1 | type==2 | type==6 | type== 7 ) // regular/other employment
keep if ( type==1 | type==2 | type==3 | type==4 | type==5 | type==6 | type==7  | type==. ) // total employment

gen regothft = ( type==1 | type==6 )

keep prs_id year beh_tag_entg duration inflow_year_01 employment_year_01 isco08_4_imp nuts07_3_fua_adj_work betnr ieb_fall_id wz08_2_imp regothft  // start end type


sort prs_id year


*find main job per person in the year

rename inflow_year_01 inflow
rename employment_year_01 employment

tab inflow, m
tab employment, m


gen wage_sum = beh_tag_entg * duration
label variable wage_sum "Payroll"

drop beh_tag_entg

order prs_id year wage_sum duration inflow employment isco08_4_imp nuts07_3_fua_adj_work betnr ieb_fall_id wz08_2_imp regothft  // start end type


save "$data\HHI_Arnold_V1.dta", replace




		
	

*** second preliminary step: construct a variable identifying those who remain in the firmXmunicipality the year after
*absent/present the year after


use "$data\HHI_Arnold_V1.dta", replace

keep prs_id betnr year ieb_fall_id duration 
gen PFy = (duration!=.)

collapse (max) PFy, by(prs_id betnr year)
rename year an
compress

replace an = an-1

tab an, m // should match with years 2012-2017


drop if an==2010 // $minyear - 1 = t+1 = 2011, i.e. for t=2010 (not part of 2012-2017 and therefore irrelevant)
drop if an==2011 // $minyear     = t+1 = 2012, i.e. for t=2011 (not part of 2012-2017 and therefore irrelevant)



rename PFy PFysircom
sort prs_id betnr an
order  prs_id betnr an
save "$data\PFSircom.dta", replace

collapse (max) PFysircom, by(prs_id an)
rename PFysircom PFy
sort prs_id an
save "$data\PF.dta", replace






***** First step: create a database with variables for observations at t and at t-1 (to avoid tsetting)

** create a dataset with relevant variables for job matches in the previous year

use "$data\HHI_Arnold_V1.dta", clear

clonevar an = year // create numeric variable for years
replace an=an+1

tab an, m // should match with years 2012-2017
	
drop if an==2018 // maxyear     = t-1 = 2017, i.e. for t=2018 (not part of 2012-2017 and therefore irrelevant)
drop if an==2019 // maxyear + 1 = t-1 = 2018, i.e. for t=2019 (not part of 2012-2017 and therefore irrelevant)



*** first condition for identification of main job in the year before: main job one year ago should be at least 270 days duration
keep if duration>=270
keep if regothft==1


rename isco08_4_imp isco08_4_imp_1
rename duration duration_1
rename wage_sum wage_sum_1

keep an betnr prs_id duration_1 isco08_4_imp_1 wage_sum_1


drop if isco08_4_imp==.

sort prs_id betnr an

duplicates report prs_id betnr an


save "$data\indiv_origin.dta", replace





*** merging with variable containing  current job matches


use "$data\HHI_Arnold_V1.dta", clear

clonevar an = year // create numeric variable for years

tab an, m // should match with years 2012-2017

drop if an==2011 // minyear
drop if an==2018 // maxyear 


keep if duration>=30 // note that this is the standard condition on durations - at least 9 months applies only to the year before


*keep industries

tab wz08_2_imp, m
keep if (wz08_2_imp>=5 & wz08_2_imp<=82) | wz08_2_imp==90 | (wz08_2_imp>=92 & wz08_2_imp<=96)  // keep only non-agricultural business sector



rename inflow Hire
rename employment Emp1y

								

*keep full-timers only and only if present the year after (even if not full-time)
keep if regothft==1


*find stayers the year after
drop if an==2018 // $maxyear
sort prs_id betnr an
merge 1:1 prs_id betnr an using "$data\PFSircom.dta", keepusing(PFysircom) // m:1 = error corrected for DK and PT
tab an _merge, m nofreq row
tab _merge PFysircom , m
drop if _merge==2
drop _merge		


keep if PFysircom ==1 // neutralise this if we do not use the condition of present the year after


* merging with records of the previous year				
sort prs_id betnr an
merge 1:1 prs_id betnr an using "$data\indiv_origin.dta"
rename _merge mergeorigin // _merge==1 & _merge==2 are kept!


sort prs_id an

* saving a temporary file containing, on the same line, 
save "$data\temp_t.dta", replace



*** second step: identifying the main job previous year among those with at least 30 days duration
* looping over years


foreach y of numlist 2012/2017 {
	
	
	display "Year: `y'"
	
	quietly {
	
		use "$data\temp_t.dta", clear

		gen p1=1 
		
		keep if an==`y'
		
		
		* second condition: pick that with the same occupation, if there is any
		
		ge occorigin = .
		
		levelsof isco08_4_imp_1, local(isco)

		foreach p of local isco {
			
			*disp 2014 `p'
			
			
			
				
			gen p1_`p' = (isco08_4_imp_1==`p')
			egen maxp1_`p' = max(p1_`p'), by(prs_id)
			replace occorigin = `p' if isco08_4_imp==`p' & maxp1_`p'==1
			drop p1_`p' maxp1_`p'
			
			
			
		}
		
		* indicators for max duration, max hours (if same duration) and max salary (if same duration and hours)
		
		egen maxdp = max(duration_1), by(prs_id)	
		
		egen maxw = max(wage_sum_1)	if abs(maxdp-duration_1)<1, by(prs_id)
		
		** NOTE: in order to "transfer" the occupation of origin from one job match the year before to a current one, I use the operator "mode"
		* which works also for alphanumeric variables
		
		* third condition: pick the one with the longest duration, if there are no ties
		* identify occupations of job matches with longest duration 
		
		gen occmode = isco08_4_imp_1 if abs(maxdp-duration_1)<1 & occorigin==.
		
		* tag = number of maximum duration minus 1 per individual
		duplicates tag prs_id if occmode!=., gen(tag)
		
		* tag2 = number of maximum duration minus 1 per individual and occupation
		duplicates tag prs_id occmode if occmode!=., gen(tag2)
		
		* choose the occupation with the modal maximum duration if this is unique (per individual)
		egen mode = mode(occmode) if tag==tag2, by(prs_id)
		replace occorigin = mode if occorigin==.
		drop mode occmode tag tag2

		* fourth condition: among the new ties, pick the one with the longest hours, if there are no new ties 
		* (occmode, tag, tag2 & mode play the same role as before)
		*ge occmode=isco08_4_imp_1 if abs(maxdp-duration_1)<1&abs(maxh-nbheur_1)<1
		*duplicates tag prs_id if occmode!=., ge(tag)
		*duplicates tag prs_id occmode if occmode!=., ge(tag2)
		*egen mode=mode(occmode) if tag==tag2, by(prs_id)
		*replace occorigin=mode if occorigin==.
		*drop mode occmode tag tag2
		
		* fifth condition: among the new ties, pick the one with the highest salary, if there are no new ties
		* (occmode, tag, tag2 & mode play the same role as before)
		gen occmode = isco08_4_imp_1 if abs(maxdp-duration_1)<1 & abs(maxw-wage_sum_1)<1
		duplicates tag prs_id if occmode!=., gen(tag)
		duplicates tag prs_id occmode if occmode!=., gen(tag2)
		egen mode = mode(occmode) if tag==tag2, by(prs_id)
		replace occorigin = mode if occorigin==.
		drop mode occmode tag tag2
		
		* sixth condition: among the new ties, pick the most frequent, if there are no new ties
		gen occmode = isco08_4_imp_1 if abs(maxdp-duration_1)<1 & abs(maxw-wage_sum_1)<1 & occorigin==.
		egen mode = mode(occmode), by(prs_id)
		replace occorigin = mode if occorigin==.
		drop mode occmode

		* seventh condition: among the new ties, pick one at random
		set seed 1 // necessitates that seed (which was globally set in master file), must be reset before wage imputation
		gen u = runiform()
		gen d = abs((_n/_N)-u)
		egen mind=min(d) if abs(maxdp-duration_1)<1 & abs(maxw-wage_sum_1)<1 & occorigin==., by(prs_id)
		gen occmode = isco08_4_imp_1 if abs(maxdp-duration_1)<1 & abs(maxw-wage_sum_1)<1 & abs(mind-d)<0.00000001 & occorigin==.
		egen mode = mode(occmode), by(prs_id)
		replace occorigin = mode if occorigin==.
		drop mode occmode
		
		
	** cleaning up (normally not needed)

		keep if isco08_4_imp!=.
		keep if occorigin!=.
		
		compress
		
		save "$data\temp_t`y'.dta", replace
		
	}	
}






*** third step: construct a squared matrix of occupation

use "$data\LMC_4_4_1218.dta", clear

collapse (sum) L_year_01_4_4, by(isco08_4_imp)
ge one=1
rename L_year_01_4_4 Z_P00
sort one
save "$data\pcs_list.dta", replace


rename isco08_4_imp occorigin
rename Z_P00 Z_P01
sort one
joinby one using "$data\pcs_list.dta"

keep isco08_4_imp occorigin Z_P01 Z_P00
sort isco08_4_imp occorigin
save "$data\pcs_squared.dta", replace



*** fourth step: transition probabilities and factors (that is relative probabilities divided by relative employment)

* create a frequency dataset by current and previous year occupations (main job only as defined above for previous year) 

clear
set obs 1
gen v1 =. 
save "$data\tprob.dta", replace

foreach y of numlist 2012/2017 {
	
	use "$data\temp_t`y'.dta", clear
	collapse (sum) p1, by(occorigin isco08_4_imp)
	replace p1=0 if p1==.
	gen year = `y'
	append using "$data\tprob.dta"
	save "$data\tprob.dta", replace

	
}

drop if p1==.

label values occorigin isco08_4



* summing frequency over years

collapse (sum) p1, by(isco08_4_imp occorigin)

label var p1 "frequency of occupation couple"

sort isco08_4_imp occorigin

merge 1:1 isco08_4_imp occorigin using "$data\pcs_squared.dta"
drop if _merge==1

replace p1=0 if p1==.

sort isco08_4_imp occorigin


* marginal distributions

egen den0=total(p1), by(isco08_4_imp) // occupation current year
egen den1=total(p1), by(occorigin) // occupation year before

* probability of a given occupation the year before conditional on the occupation of origin

gen prob = p1/den1
replace prob = 0 if prob==.

* probability of remaining in the same occupation conditional on the occupation of origin

gen tden = prob if occorigin==isco08_4_imp

* reporting the probability of remaining in the same occupation conditional on the occupation of origin to all couples with same occorigin

egen den = max(tden), by(occorigin)

* relative probability (as in Arnold's formula	

gen relprob = prob/den

replace relprob = 0 if relprob==.

* relative factor (as in Arnold's: (Prob_m_to_k/Prob_m_to_m)/(E(Lk/ELm)
* assumption E(Lk/ELm) in Arnold can be approximated by Z_P00/Z_P01

gen relfactor=relprob*(Z_P01/Z_P00)


drop den tden den1 den0 Z_P00 Z_P01 _merge

sort isco08_4_imp occorigin

compress

save "$data\tprob.dta", replace	
	
	
	
	
use "$data\tprob.dta", replace	

rename occorigin isco08_4_m
rename isco08_4_imp isco08_4_k



rename relfactor alpha_m_k
	
sort isco08_4_m isco08_4_k

label variable isco08_4_m "Occupational Unit Group (ISCO08-4)"
label variable alpha_m_k "Weighting Factor Based on Occupational Mobility"
	
	
keep isco08_4_m isco08_4_k alpha_m_k	
order isco08_4_m isco08_4_k alpha_m_k	

	
save "$data\tprob.dta", replace	

		




*** 1.5.2 STEP-WISE CALCULATION OF ARNOLD-TYPE HHI***


* sixth step: final HHI calculation


* create minimal dataset on employment shares for later loop across ISCO-4 occupations

use "$data\LMC_4_1218.dta", clear

gen isco08_4_m = .
label variable isco08_4_m "Occupational Unit Group (ISCO08-4)"
label values isco08_4_m isco08_4

rename isco08_4_imp isco08_4_k

keep year betnr isco08_4_k nuts07_3_fua_adj_work L_year_01_jt H_year_01_jt isco08_4_m

order isco08_4_m nuts07_3_fua_adj_work year isco08_4_k betnr L_year_01_jt H_year_01_jt 
sort isco08_4_m nuts07_3_fua_adj_work year isco08_4_k betnr


save "$data\HHI_Arnold\LMC_Arn_4_4_1218_Isco_V1.dta", replace





foreach x of numlist 110 210 310 1111 1112 1114 1120 1211 1212 1213 1219 1221 1222 1223 1312 1321 1322 1323 1324 1330 1342 1343 1344 1345 1346 1349 1411 1412 1420 1431 1439 2111 2112 2113 2114 2120 2131 2132 2133 2141 2142 2143 2144 2145 2146 2149 /// 
					 2151 2152 2153 2161 2162 2163 2164 2165 2166 2211 2212 2221 2222 2230 2240 2250 2261 2262 2263 2264 2265 2266 2267 2269 2310 2320 2330 2341 2351 2352 2353 2354 2355 2356 2359 2411 2412 2413 2421 2422 2423 2424 2431 2432 2433 ///
					 2434 2511 2512 2513 2514 2519 2521 2522 2523 2529 2611 2612 2619 2621 2622 2631 2632 2633 2634 2635 2636 2641 2642 2643 2651 2652 2653 2654 2655 2656 2659 3111 3112 3113 3114 3115 3116 3117 3118 3119 3121 3122 3123 3131 3132 ///
					 3133 3134 3135 3141 3142 3143 3151 3152 3153 3154 3155 3211 3212 3213 3214 3221 3222 3240 3251 3252 3253 3254 3255 3256 3257 3258 3259 3311 3312 3313 3314 3315 3321 3322 3323 3324 3331 3332 3333 3334 3339 3341 3342 3343 3344 ///
					 3351 3352 3353 3354 3355 3359 3411 3412 3413 3421 3422 3423 3431 3432 3433 3434 3435 3511 3512 3513 3514 3521 3522 4110 4120 4131 4132 4211 4212 4213 4214 4221 4222 4224 4225 4226 4227 4311 4312 4321 4322 4323 4411 4412 4413 ///
					 4415 4416 4419 5111 5112 5113 5120 5131 5132 5141 5142 5151 5152 5153 5163 5164 5165 5169 5211 5221 5222 5223 5230 5241 5245 5246 5249 5311 5312 5321 5322 5329 5411 5412 5413 5414 5419 6111 6112 6113 6121 6122 6123 6129 6130 ///
					 6210 6221 6222 7111 7112 7113 7114 7115 7119 7121 7122 7123 7124 7125 7126 7127 7131 7132 7133 7211 7212 7213 7214 7221 7222 7223 7224 7231 7232 7233 7234 7311 7312 7313 7314 7315 7316 7317 7319 7321 7322 7323 7411 7412 7413 ///
					 7421 7422 7511 7512 7513 7515 7521 7522 7523 7531 7532 7533 7534 7535 7536 7541 7542 7543 7544 7549 8111 8112 8113 8114 8121 8122 8131 8132 8141 8142 8143 8151 8152 8153 8154 8157 8159 8160 8171 8172 8181 8189 8211 8212 8311 ///
					 8312 8322 8331 8332 8341 8342 8343 8344 8350 9111 9112 9122 9123 9129 9211 9212 9214 9215 9216 9311 9312 9313 9329 9332 9333 9334 9412 9612 9613 9621 9623 9629  {
		 
				 
					 					 
	display "ISCO-4 Occupation: `x' "		
	
	quietly {
	
		use "$data\HHI_Arnold\LMC_Arn_4_4_1218_Isco_V1.dta", clear						

		replace isco08_4_m = `x'


		merge m:1 isco08_4_m isco08_4_k using "$data\tprob.dta", keepusing(alpha_m_k)
		drop if _merge==2
		drop _merge
		

		
		
		rename isco08_4_m isco08_4_imp

		sort isco08_4_imp nuts07_3_fua_adj_work year betnr isco08_4_k

		order isco08_4_imp nuts07_3_fua_adj_work year betnr isco08_4_k L_year_01_jt H_year_01_jt alpha_m_k
		
		

		gen L_Arn_year_01_jot = L_year_01_jt * alpha_m_k // for employment (used for HHI calculation): adjust workers in the very same labor market with weight 1, and all other labor markets with weight alpha_k_m
		
			bys isco08_4_imp nuts07_3_fua_adj_work year isco08_4_k: egen L_k_year_01 = total(L_year_01_jt) 
			bys isco08_4_imp nuts07_3_fua_adj_work year isco08_4_k: egen N_L_k_year_01 = sum(L_year_01_jt>=1)
			
			gen L2_year_01_jt = 0
			replace L2_year_01_jt = ( L_k_year_01 / N_L_k_year_01 ) if L_year_01_jt>=1
			
			drop L_k_year_01 N_L_k_year_01
			
		gen L_Arn2_year_01_jot = L2_year_01_jt * alpha_m_k	
			
		
		rename L_year_01_jt L_year_01_jot
		rename H_year_01_jt H_year_01_jot
		
		replace L_year_01_jot = 0 if isco08_4_k!=`x' // for employment (= frequency weight): count only workers in the very same labor market, also necessary for standard HHI
		replace H_year_01_jot = 0 if isco08_4_k!=`x' // for hires (= frequency weight): count only hires in the very same labor market

		collapse (sum) L_Arn_year_01_jt=L_Arn_year_01_jot L_Arn2_year_01_jt=L_Arn2_year_01_jot H_year_01_jt=H_year_01_jot L_year_01_jt=L_year_01_jot, by(betnr isco08_4_imp nuts07_3_fua_adj_work year)


		
		bysort isco08_4_imp nuts07_3_fua_adj_work year: egen H_year_01_4_4 = total(H_year_01_jt) // number of hires per labor market --> frequency weight
		bysort isco08_4_imp nuts07_3_fua_adj_work year: egen L_year_01_4_4 = total(L_year_01_jt) // number of workers per labor market --> frequency weight
		bysort isco08_4_imp nuts07_3_fua_adj_work year: egen L_Arn_year_01_4_4 = total(L_Arn_year_01_jt) // number of workers per labor market --> necessary for computation of HHI
		bysort isco08_4_imp nuts07_3_fua_adj_work year: egen L_Arn2_year_01_4_4 = total(L_Arn2_year_01_jt) // number of workers per labor market --> necessary for computation of HHI

		
		bysort isco08_4_imp nuts07_3_fua_adj_work year: egen N_L_year_01_4_4 = sum(L_year_01_jt>=1) // number of employing establishments per labor market --> necessary for computation of INS
		*bysort isco08_4_imp nuts07_3_fua_adj_work year: egen N_L_Arn_year_01_4_4 = sum(L_Arn_year_01_jt>0) // number of employing establishments per labor market --> necessary for computation of INS

		
		
		*gen L_Arn_year_01_jt_weight = ( L_Arn_year_01_jt>=1 )
		*replace L_Arn_year_01_jt_weight = L_Arn_year_01_jt_weight * alpha_k_m
		
		*drop isco08_4_k alpha_k_m
		
		*bysort isco08_4_imp nuts07_3_fua_adj_work year: egen N_L_Arn_year_01_4_4 = sum(L_Arn_year_01_jt_weight>=1) // number of hiring establishments per labor market --> necessary for computation of INS

		gen s_L_year_01_4_4_jt = L_year_01_jt / L_year_01_4_4
		gen s_L_Arn_year_01_4_4_jt = L_Arn_year_01_jt / L_Arn_year_01_4_4
		gen s_L_Arn2_year_01_4_4_jt = L_Arn2_year_01_jt / L_Arn2_year_01_4_4



		count if s_L_Arn_year_01_4_4_jt==0

		drop H_year_01_jt L_year_01_jt L_Arn_year_01_jt L_Arn2_year_01_jt
		
		
		


		*** HERFINDAHL-HIRSCHMAN INDEX

		gen s_j_2 = (s_L_year_01_4_4_jt)^2
		gen s_Arn_j_2 = (s_L_Arn_year_01_4_4_jt)^2
		gen s_Arn2_j_2 = (s_L_Arn2_year_01_4_4_jt)^2

		bysort isco08_4_imp nuts07_3_fua_adj_work year: egen HHI_year_01_4_4 = total(s_j_2)
		bysort isco08_4_imp nuts07_3_fua_adj_work year: egen HHI_Arn_year_01_4_4 = total(s_Arn_j_2)
		bysort isco08_4_imp nuts07_3_fua_adj_work year: egen HHI_Arn2_year_01_4_4 = total(s_Arn2_j_2)


		replace HHI_year_01_4_4 = . if HHI_year_01_4_4==0 & s_L_year_01_4_4_jt==. // sum of missings = 0 --> only relevant for markets and hiring concepts with zero hires
		replace HHI_Arn_year_01_4_4 = . if HHI_Arn_year_01_4_4==0 & s_L_Arn_year_01_4_4_jt==. // sum of missings = 0 --> only relevant for markets and hiring concepts with zero hires
		replace HHI_Arn2_year_01_4_4 = . if HHI_Arn2_year_01_4_4==0 & s_L_Arn2_year_01_4_4_jt==. // sum of missings = 0 --> only relevant for markets and hiring concepts with zero hires

		drop s_j_2 s_Arn_j_2 s_Arn2_j_2 s_L_year_01_4_4_jt s_L_Arn_year_01_4_4_jt s_L_Arn2_year_01_4_4_jt
		
		
		
		*** INVERSE NUMBER OF SUBJECTS

		gen INS_year_01_4_4 = 1 / N_L_year_01_4_4
		*gen INS_Arn_year_01_4_4 = 1 / N_L_Arn_year_01_4_4
				
		drop N_L_year_01_4_4 // N_L_Arn_year_01_4_4
				
		rename HHI_Arn2_year_01_4_4 INS_Arn_year_01_4_4
		
		
		*collapse information on concentration measures
		
		sort isco08_4_imp nuts07_3_fua_adj_work year
		collapse (first) HHI_year_01_4_4 HHI_Arn_year_01_4_4 INS_year_01_4_4 INS_Arn_year_01_4_4 ///
						 L_year_01_4_4  ///
						 L_Arn_year_01_4_4  /// 
						 H_year_01_4_4  ///
						 , by(isco08_4_imp nuts07_3_fua_adj_work year)
		
		order isco08_4_imp nuts07_3_fua_adj_work year
		sort isco08_4_imp nuts07_3_fua_adj_work year
		


		save "$data\HHI_Arnold\LMC_Arn_4_4_1218_Isco`x'_V2.dta", replace
		


		use "$data\BeH_FUA.dta", clear
		
		rename nuts07_3_fua_adj nuts07_3_fua_adj_work
		
		keep nuts07_3_fua_adj_work
		duplicates drop
		
		gen isco08_4_imp = `x'
		label values isco08_4_imp isco08_4
		
		order isco08_4_imp nuts07_3_fua_adj_work		
		
	
		*add year variable

		expand 6 // 6 years (2012-2017)

		sort isco08_4_imp nuts07_3_fua_adj_work

		by isco08_4_imp nuts07_3_fua_adj_work : gen year = _n + 2011  // Y regions * Z industries * T years = YZT observations


		merge 1:1 isco08_4_imp nuts07_3_fua_adj_work year using "$data\HHI_Arnold\LMC_Arn_4_4_1218_Isco`x'_V2.dta"

	
		sort isco08_4_imp nuts07_3_fua_adj_work year

		replace HHI_year_01_4_4 = . if _merge==1
		replace HHI_Arn_year_01_4_4 = . if _merge==1
		
		replace INS_year_01_4_4 = . if _merge==1
		replace INS_Arn_year_01_4_4 = . if _merge==1
		
		replace L_year_01_4_4 = 0 if _merge==1
		replace L_Arn_year_01_4_4 = 0 if _merge==1			
		replace H_year_01_4_4 = 0 if _merge==1

		drop _merge

		save "$data\HHI_Arnold\LMC_Arn_4_4_1218_Isco`x'_V3.dta", replace

		
		
		
		

		*** IV: LEAVE-ONE-OUT-MEAN FOR INVERSE NUMBER OF HIRING ESTABLISHMENTS IN SAME OCCUPATION-YEAR 


		use "$data\HHI_Arnold\LMC_Arn_4_4_1218_Isco`x'_V3.dta", clear
				
		keep isco08_4_imp year nuts07_3_fua_adj_work INS_year_01_4_4 INS_Arn_year_01_4_4 HHI_year_01_4_4 HHI_Arn_year_01_4_4
		order isco08_4_imp year nuts07_3_fua_adj_work INS_year_01_4_4 INS_Arn_year_01_4_4 HHI_year_01_4_4 HHI_Arn_year_01_4_4
		sort isco08_4_imp year nuts07_3_fua_adj_work INS_year_01_4_4 INS_Arn_year_01_4_4 HHI_year_01_4_4 HHI_Arn_year_01_4_4
		

		
			
		gen ln_INS_year_01_4_4 = ln(INS_year_01_4_4)
		gen ln_INS_Arn_year_01_4_4 = ln(INS_Arn_year_01_4_4)
		gen ln_HHI_year_01_4_4 = ln(HHI_year_01_4_4)
		gen ln_HHI_Arn_year_01_4_4 = ln(HHI_Arn_year_01_4_4)

		drop INS_year_01_4_4 INS_Arn_year_01_4_4 HHI_year_01_4_4 HHI_Arn_year_01_4_4

		bysort isco08_4_imp year: egen ln_INS_mean_year_01_4_4 = mean(ln_INS_year_01_4_4)
		bysort isco08_4_imp year: egen ln_INS_Arn_mean_year_01_4_4 = mean(ln_INS_Arn_year_01_4_4)
		bysort isco08_4_imp year: egen ln_HHI_mean_year_01_4_4 = mean(ln_HHI_year_01_4_4)
		bysort isco08_4_imp year: egen ln_HHI_Arn_mean_year_01_4_4 = mean(ln_HHI_Arn_year_01_4_4)

		by isco08_4_imp year: egen n_INS_year_01_4_4 = sum(!missing(ln_INS_year_01_4_4))
		by isco08_4_imp year: egen n_INS_Arn_year_01_4_4 = sum(!missing(ln_INS_Arn_year_01_4_4))
		by isco08_4_imp year: egen n_HHI_year_01_4_4 = sum(!missing(ln_HHI_year_01_4_4))
		by isco08_4_imp year: egen n_HHI_Arn_year_01_4_4 = sum(!missing(ln_HHI_Arn_year_01_4_4))
		
		
		*tab n_INS_year_01_4_4 , m
		*tab n_INS_Arn_year_01_4_4 , m
		*tab n_HHI_year_01_4_4 , m
		*tab n_HHI_Arn_year_01_4_4 , m
		
		gen ln_INS_loom_year_01_4_4 = [ ( ln_INS_mean_year_01_4_4 * n_INS_year_01_4_4 ) - ln_INS_year_01_4_4 ] / (n_INS_year_01_4_4-1)
		gen ln_INS_Arn_loom_year_01_4_4 = [ ( ln_INS_Arn_mean_year_01_4_4 * n_INS_Arn_year_01_4_4 ) - ln_INS_Arn_year_01_4_4  ] / (n_INS_Arn_year_01_4_4-1)
		gen ln_HHI_loom_year_01_4_4 = [ ( ln_HHI_mean_year_01_4_4 * n_HHI_year_01_4_4 ) - ln_HHI_year_01_4_4 ] / (n_HHI_year_01_4_4-1)
		gen ln_HHI_Arn_loom_year_01_4_4 = [ ( ln_HHI_Arn_mean_year_01_4_4 * n_HHI_Arn_year_01_4_4 ) - ln_HHI_Arn_year_01_4_4  ] / (n_HHI_Arn_year_01_4_4-1)

		replace ln_INS_loom_year_01_4_4 = . if ln_INS_year_01_4_4==. 
		replace ln_INS_Arn_loom_year_01_4_4 = . if ln_INS_Arn_year_01_4_4==. 
		replace ln_HHI_loom_year_01_4_4 = . if ln_HHI_year_01_4_4==. 
		replace ln_HHI_Arn_loom_year_01_4_4 = . if ln_HHI_Arn_year_01_4_4==. 

		keep isco08_4_imp year nuts07_3_fua_adj_work ln_INS_loom_year_01_4_4 ln_INS_Arn_loom_year_01_4_4 ln_HHI_loom_year_01_4_4 ln_HHI_Arn_loom_year_01_4_4
		
	
		merge 1:1 isco08_4_imp year nuts07_3_fua_adj_work using "$data\HHI_Arnold\LMC_Arn_4_4_1218_Isco`x'_V3.dta"
		drop _merge

		
		sort isco08_4_imp nuts07_3_fua_adj_work year
		
		
		save "$data\HHI_Arnold\LMC_Arn_4_4_1218_Isco`x'_V4.dta", replace

		erase "$data\HHI_Arnold\LMC_Arn_4_4_1218_Isco`x'_V2.dta"
		erase "$data\HHI_Arnold\LMC_Arn_4_4_1218_Isco`x'_V3.dta"

			
	
	}		
}	
	
		
		
		
		
		
		
		
		
		
		
		
		
		
		
		
		
		
		
		
		
	




	
clear

foreach x of numlist 110 210 310 1111 1112 1114 1120 1211 1212 1213 1219 1221 1222 1223 1312 1321 1322 1323 1324 1330 1342 1343 1344 1345 1346 1349 1411 1412 1420 1431 1439 2111 2112 2113 2114 2120 2131 2132 2133 2141 2142 2143 2144 2145 2146 2149 /// 
					 2151 2152 2153 2161 2162 2163 2164 2165 2166 2211 2212 2221 2222 2230 2240 2250 2261 2262 2263 2264 2265 2266 2267 2269 2310 2320 2330 2341 2351 2352 2353 2354 2355 2356 2359 2411 2412 2413 2421 2422 2423 2424 2431 2432 2433 ///
					 2434 2511 2512 2513 2514 2519 2521 2522 2523 2529 2611 2612 2619 2621 2622 2631 2632 2633 2634 2635 2636 2641 2642 2643 2651 2652 2653 2654 2655 2656 2659 3111 3112 3113 3114 3115 3116 3117 3118 3119 3121 3122 3123 3131 3132 ///
					 3133 3134 3135 3141 3142 3143 3151 3152 3153 3154 3155 3211 3212 3213 3214 3221 3222 3240 3251 3252 3253 3254 3255 3256 3257 3258 3259 3311 3312 3313 3314 3315 3321 3322 3323 3324 3331 3332 3333 3334 3339 3341 3342 3343 3344 ///
					 3351 3352 3353 3354 3355 3359 3411 3412 3413 3421 3422 3423 3431 3432 3433 3434 3435 3511 3512 3513 3514 3521 3522 4110 4120 4131 4132 4211 4212 4213 4214 4221 4222 4224 4225 4226 4227 4311 4312 4321 4322 4323 4411 4412 4413 ///
					 4415 4416 4419 5111 5112 5113 5120 5131 5132 5141 5142 5151 5152 5153 5163 5164 5165 5169 5211 5221 5222 5223 5230 5241 5245 5246 5249 5311 5312 5321 5322 5329 5411 5412 5413 5414 5419 6111 6112 6113 6121 6122 6123 6129 6130 ///
					 6210 6221 6222 7111 7112 7113 7114 7115 7119 7121 7122 7123 7124 7125 7126 7127 7131 7132 7133 7211 7212 7213 7214 7221 7222 7223 7224 7231 7232 7233 7234 7311 7312 7313 7314 7315 7316 7317 7319 7321 7322 7323 7411 7412 7413 ///
					 7421 7422 7511 7512 7513 7515 7521 7522 7523 7531 7532 7533 7534 7535 7536 7541 7542 7543 7544 7549 8111 8112 8113 8114 8121 8122 8131 8132 8141 8142 8143 8151 8152 8153 8154 8157 8159 8160 8171 8172 8181 8189 8211 8212 8311 ///
					 8312 8322 8331 8332 8341 8342 8343 8344 8350 9111 9112 9122 9123 9129 9211 9212 9214 9215 9216 9311 9312 9313 9329 9332 9333 9334 9412 9612 9613 9621 9623 9629 {
			
		 	
	display "ISCO-4 Occupation: `x' "		
	
	
	quietly append using "$data\HHI_Arnold\LMC_Arn_4_4_1218_Isco`x'_V4.dta"
	
	}
	
	
sort isco08_4_imp nuts07_3_fua_adj_work year	

order isco08_4_imp nuts07_3_fua_adj_work year HHI_year_01_4_4 INS_year_01_4_4 HHI_Arn_year_01_4_4 INS_Arn_year_01_4_4 ln_INS_loom_year_01_4_4 ln_INS_Arn_loom_year_01_4_4 ln_HHI_loom_year_01_4_4 ln_HHI_Arn_loom_year_01_4_4 L_year_01_4_4 L_Arn_year_01_4_4 H_year_01_4_4



rename HHI_year_01_4_4 HHI_L_year_01_4_4  
rename INS_year_01_4_4 INS_L_year_01_4_4
rename HHI_Arn_year_01_4_4 HHI_L_Arn_year_01_4_4 
rename INS_Arn_year_01_4_4 INS_L_Arn_year_01_4_4
rename ln_INS_loom_year_01_4_4 ln_INS_L_loom_year_01_4_4 
rename ln_INS_Arn_loom_year_01_4_4 ln_INS_L_Arn_loom_year_01_4_4
rename ln_HHI_loom_year_01_4_4 ln_HHI_L_loom_year_01_4_4 
rename ln_HHI_Arn_loom_year_01_4_4 ln_HHI_L_Arn_loom_year_01_4_4


**# Bookmark #1

label variable isco08_4_imp "Occupational Unit Group (ISCO08-4)"
label variable year "Year"

label variable HHI_L_year_01_4_4 "Herfindahl-Hirschman Index"
label variable HHI_L_Arn_year_01_4_4 "Herfindahl-Hirschman Index (Arnold-type)"

label variable INS_L_year_01_4_4 "Inverse Number of Subjects"
label variable INS_L_Arn_year_01_4_4 "Inverse Number of Subjects (Arnold-type)"

label variable ln_INS_L_loom_year_01_4_4 "LOOM for Inverse Number of Subjects"
label variable ln_INS_L_Arn_loom_year_01_4_4 "Loom for Inverse Number of Subjects (Arnold-type)"

label variable ln_HHI_L_loom_year_01_4_4 "LOOM for HHI"
label variable ln_HHI_L_Arn_loom_year_01_4_4 "Loom for HHI (Arnold-type)"

label variable L_year_01_4_4 "Number of Workers"
label variable L_Arn_year_01_4_4 "Number of Workers (Arnold-type)"
label variable H_year_01_4_4 "Number of Hires"	

	
save "$data\LMC_Arn_4_4_1218.dta", replace	
	

	
	
	
	
	
	
*test


use "$data\LMC_L_4_4_1218.dta", replace		
	
keep isco08_4_imp nuts07_3_fua_adj_work year HHI_L_year_01_4_4 INS_L_year_01_4_4 ln_INS_L_loom_year_01_4_4 ln_HHI_L_loom_year_01_4_4 H_year_01_4_4 L_year_01_4_4 

rename HHI_L_year_01_4_4 HHI_L_year_01_4_4_old
rename INS_L_year_01_4_4 INS_L_year_01_4_4_old
rename ln_INS_L_loom_year_01_4_4 ln_INS_L_loom_year_01_4_4_old
rename ln_HHI_L_loom_year_01_4_4 ln_HHI_L_loom_year_01_4_4_old

rename H_year_01_4_4 H_year_01_4_4_old
rename L_year_01_4_4 L_year_01_4_4_old


merge 1:1 isco08_4_imp nuts07_3_fua_adj_work year using "$data\LMC_Arn_4_4_1218.dta"
*keep if _merge==3
drop _merge



count if HHI_L_year_01_4_4==HHI_L_year_01_4_4_old // always the same
count if INS_L_year_01_4_4==INS_L_year_01_4_4_old // always the same
count if ln_INS_L_loom_year_01_4_4==ln_INS_L_loom_year_01_4_4_old // always the same
count if ln_HHI_L_loom_year_01_4_4==ln_HHI_L_loom_year_01_4_4_old // always the same

count if H_year_01_4_4==H_year_01_4_4_old // always the same
count if L_year_01_4_4==L_year_01_4_4_old // always the same


count if HHI_L_year_01_4_4==. // missing when zero workers
count if INS_L_year_01_4_4==. // missing when zero workers

count if HHI_L_Arn_year_01_4_4==. // never missing
count if INS_L_Arn_year_01_4_4==. // never missing




drop *_old

sum HHI_L_year_01_4_4 HHI_L_Arn_year_01_4_4 INS_L_year_01_4_4 INS_L_Arn_year_01_4_4 ln_INS_L_loom_year_01_4_4 ln_INS_L_Arn_loom_year_01_4_4 ln_HHI_L_Arn_loom_year_01_4_4 L_year_01_4_4 L_Arn_year_01_4_4 H_year_01_4_4

hist HHI_L_year_01_4_4
hist HHI_L_Arn_year_01_4_4

hist INS_L_year_01_4_4
hist INS_L_Arn_year_01_4_4

count if HHI_L_year_01_4_4>=HHI_L_Arn_year_01_4_4
count if HHI_L_year_01_4_4<HHI_L_Arn_year_01_4_4

count if INS_L_year_01_4_4>=INS_L_Arn_year_01_4_4
count if INS_L_year_01_4_4<INS_L_Arn_year_01_4_4

br if HHI_L_year_01_4_4<HHI_L_Arn_year_01_4_4
br if INS_L_year_01_4_4<INS_L_Arn_year_01_4_4


gen ln_HHI_L_year_01_4_4 = ln(HHI_L_year_01_4_4)
gen ln_HHI_L_Arn_year_01_4_4 = ln(HHI_L_Arn_year_01_4_4)

correlate HHI_L_year_01_4_4 HHI_L_Arn_year_01_4_4 
correlate ln_HHI_L_year_01_4_4 ln_HHI_L_Arn_year_01_4_4 ln_INS_L_loom_year_01_4_4 ln_INS_L_Arn_loom_year_01_4_4

correlate HHI_L_year_01_4_4 HHI_L_Arn_year_01_4_4 [fweight=H_year_01_4_4]
correlate ln_HHI_L_year_01_4_4 ln_HHI_L_Arn_year_01_4_4 ln_INS_L_loom_year_01_4_4 ln_INS_L_Arn_loom_year_01_4_4 [fweight=H_year_01_4_4]





